# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #

from .account_ttl import AccountTtl
from .address import Address
from .animated_chat_photo import AnimatedChatPhoto
from .animation import Animation
from .animations import Animations
from .audio import Audio
from .authentication_code_info import AuthenticationCodeInfo
from .authentication_code_type import (
    AuthenticationCodeType,
    AuthenticationCodeTypeCall,
    AuthenticationCodeTypeFlashCall,
    AuthenticationCodeTypeSms,
    AuthenticationCodeTypeTelegramMessage,
)
from .authorization_state import (
    AuthorizationState,
    AuthorizationStateClosed,
    AuthorizationStateClosing,
    AuthorizationStateLoggingOut,
    AuthorizationStateReady,
    AuthorizationStateWaitCode,
    AuthorizationStateWaitEncryptionKey,
    AuthorizationStateWaitOtherDeviceConfirmation,
    AuthorizationStateWaitPassword,
    AuthorizationStateWaitPhoneNumber,
    AuthorizationStateWaitRegistration,
    AuthorizationStateWaitTdlibParameters,
)
from .auto_download_settings import AutoDownloadSettings
from .auto_download_settings_presets import AutoDownloadSettingsPresets
from .background import Background
from .background_fill import (
    BackgroundFill,
    BackgroundFillFreeformGradient,
    BackgroundFillGradient,
    BackgroundFillSolid,
)
from .background_type import (
    BackgroundType,
    BackgroundTypeFill,
    BackgroundTypePattern,
    BackgroundTypeWallpaper,
)
from .backgrounds import Backgrounds
from .bank_card_action_open_url import BankCardActionOpenUrl
from .bank_card_info import BankCardInfo
from .basic_group import BasicGroup
from .basic_group_full_info import BasicGroupFullInfo
from .bot_command import BotCommand
from .bot_command_scope import (
    BotCommandScope,
    BotCommandScopeAllChatAdministrators,
    BotCommandScopeAllGroupChats,
    BotCommandScopeAllPrivateChats,
    BotCommandScopeChat,
    BotCommandScopeChatAdministrators,
    BotCommandScopeChatMember,
    BotCommandScopeDefault,
)
from .bot_commands import BotCommands
from .call import Call
from .call_discard_reason import (
    CallDiscardReason,
    CallDiscardReasonDeclined,
    CallDiscardReasonDisconnected,
    CallDiscardReasonEmpty,
    CallDiscardReasonHungUp,
    CallDiscardReasonMissed,
)
from .call_id import CallId
from .call_problem import (
    CallProblem,
    CallProblemDistortedSpeech,
    CallProblemDistortedVideo,
    CallProblemDropped,
    CallProblemEcho,
    CallProblemInterruptions,
    CallProblemNoise,
    CallProblemPixelatedVideo,
    CallProblemSilentLocal,
    CallProblemSilentRemote,
)
from .call_protocol import CallProtocol
from .call_server import CallServer
from .call_server_type import (
    CallServerType,
    CallServerTypeTelegramReflector,
    CallServerTypeWebrtc,
)
from .call_state import (
    CallState,
    CallStateDiscarded,
    CallStateError,
    CallStateExchangingKeys,
    CallStateHangingUp,
    CallStatePending,
    CallStateReady,
)
from .callback_query_answer import CallbackQueryAnswer
from .callback_query_payload import (
    CallbackQueryPayload,
    CallbackQueryPayloadData,
    CallbackQueryPayloadDataWithPassword,
    CallbackQueryPayloadGame,
)
from .can_transfer_ownership_result import (
    CanTransferOwnershipResult,
    CanTransferOwnershipResultOk,
    CanTransferOwnershipResultPasswordNeeded,
    CanTransferOwnershipResultPasswordTooFresh,
    CanTransferOwnershipResultSessionTooFresh,
)
from .chat import Chat
from .chat_action import (
    ChatAction,
    ChatActionCancel,
    ChatActionChoosingContact,
    ChatActionChoosingLocation,
    ChatActionRecordingVideo,
    ChatActionRecordingVideoNote,
    ChatActionRecordingVoiceNote,
    ChatActionStartPlayingGame,
    ChatActionTyping,
    ChatActionUploadingDocument,
    ChatActionUploadingPhoto,
    ChatActionUploadingVideo,
    ChatActionUploadingVideoNote,
    ChatActionUploadingVoiceNote,
)
from .chat_action_bar import (
    ChatActionBar,
    ChatActionBarAddContact,
    ChatActionBarInviteMembers,
    ChatActionBarReportAddBlock,
    ChatActionBarReportSpam,
    ChatActionBarReportUnrelatedLocation,
    ChatActionBarSharePhoneNumber,
)
from .chat_administrator import ChatAdministrator
from .chat_administrators import ChatAdministrators
from .chat_event import ChatEvent
from .chat_event_action import (
    ChatEventAction,
    ChatEventDescriptionChanged,
    ChatEventInviteLinkDeleted,
    ChatEventInviteLinkEdited,
    ChatEventInviteLinkRevoked,
    ChatEventInvitesToggled,
    ChatEventIsAllHistoryAvailableToggled,
    ChatEventLinkedChatChanged,
    ChatEventLocationChanged,
    ChatEventMemberInvited,
    ChatEventMemberJoined,
    ChatEventMemberJoinedByInviteLink,
    ChatEventMemberLeft,
    ChatEventMemberPromoted,
    ChatEventMemberRestricted,
    ChatEventMessageDeleted,
    ChatEventMessageEdited,
    ChatEventMessagePinned,
    ChatEventMessageTtlSettingChanged,
    ChatEventMessageUnpinned,
    ChatEventPermissionsChanged,
    ChatEventPhotoChanged,
    ChatEventPollStopped,
    ChatEventSignMessagesToggled,
    ChatEventSlowModeDelayChanged,
    ChatEventStickerSetChanged,
    ChatEventTitleChanged,
    ChatEventUsernameChanged,
    ChatEventVoiceChatCreated,
    ChatEventVoiceChatDiscarded,
    ChatEventVoiceChatMuteNewParticipantsToggled,
    ChatEventVoiceChatParticipantIsMutedToggled,
    ChatEventVoiceChatParticipantVolumeLevelChanged,
)
from .chat_event_log_filters import ChatEventLogFilters
from .chat_events import ChatEvents
from .chat_filter import ChatFilter
from .chat_filter_info import ChatFilterInfo
from .chat_invite_link import ChatInviteLink
from .chat_invite_link_count import ChatInviteLinkCount
from .chat_invite_link_counts import ChatInviteLinkCounts
from .chat_invite_link_info import ChatInviteLinkInfo
from .chat_invite_link_member import ChatInviteLinkMember
from .chat_invite_link_members import ChatInviteLinkMembers
from .chat_invite_links import ChatInviteLinks
from .chat_list import (
    ChatList,
    ChatListArchive,
    ChatListFilter,
    ChatListMain,
)
from .chat_lists import ChatLists
from .chat_location import ChatLocation
from .chat_member import ChatMember
from .chat_member_status import (
    ChatMemberStatus,
    ChatMemberStatusAdministrator,
    ChatMemberStatusBanned,
    ChatMemberStatusCreator,
    ChatMemberStatusLeft,
    ChatMemberStatusMember,
    ChatMemberStatusRestricted,
)
from .chat_members import ChatMembers
from .chat_members_filter import (
    ChatMembersFilter,
    ChatMembersFilterAdministrators,
    ChatMembersFilterBanned,
    ChatMembersFilterBots,
    ChatMembersFilterContacts,
    ChatMembersFilterMembers,
    ChatMembersFilterMention,
    ChatMembersFilterRestricted,
)
from .chat_nearby import ChatNearby
from .chat_notification_settings import ChatNotificationSettings
from .chat_permissions import ChatPermissions
from .chat_photo import ChatPhoto
from .chat_photo_info import ChatPhotoInfo
from .chat_photos import ChatPhotos
from .chat_position import ChatPosition
from .chat_report_reason import (
    ChatReportReason,
    ChatReportReasonChildAbuse,
    ChatReportReasonCopyright,
    ChatReportReasonCustom,
    ChatReportReasonFake,
    ChatReportReasonPornography,
    ChatReportReasonSpam,
    ChatReportReasonUnrelatedLocation,
    ChatReportReasonViolence,
)
from .chat_source import (
    ChatSource,
    ChatSourceMtprotoProxy,
    ChatSourcePublicServiceAnnouncement,
)
from .chat_statistics import (
    ChatStatistics,
    ChatStatisticsChannel,
    ChatStatisticsSupergroup,
)
from .chat_statistics_administrator_actions_info import ChatStatisticsAdministratorActionsInfo
from .chat_statistics_inviter_info import ChatStatisticsInviterInfo
from .chat_statistics_message_interaction_info import ChatStatisticsMessageInteractionInfo
from .chat_statistics_message_sender_info import ChatStatisticsMessageSenderInfo
from .chat_type import (
    ChatType,
    ChatTypeBasicGroup,
    ChatTypePrivate,
    ChatTypeSecret,
    ChatTypeSupergroup,
)
from .chats import Chats
from .chats_nearby import ChatsNearby
from .check_chat_username_result import (
    CheckChatUsernameResult,
    CheckChatUsernameResultOk,
    CheckChatUsernameResultPublicChatsTooMuch,
    CheckChatUsernameResultPublicGroupsUnavailable,
    CheckChatUsernameResultUsernameInvalid,
    CheckChatUsernameResultUsernameOccupied,
)
from .check_sticker_set_name_result import (
    CheckStickerSetNameResult,
    CheckStickerSetNameResultNameInvalid,
    CheckStickerSetNameResultNameOccupied,
    CheckStickerSetNameResultOk,
)
from .closed_vector_path import ClosedVectorPath
from .connected_website import ConnectedWebsite
from .connected_websites import ConnectedWebsites
from .connection_state import (
    ConnectionState,
    ConnectionStateConnecting,
    ConnectionStateConnectingToProxy,
    ConnectionStateReady,
    ConnectionStateUpdating,
    ConnectionStateWaitingForNetwork,
)
from .contact import Contact
from .count import Count
from .countries import Countries
from .country_info import CountryInfo
from .custom_request_result import CustomRequestResult
from .database_statistics import DatabaseStatistics
from .date import Date
from .date_range import DateRange
from .dated_file import DatedFile
from .deep_link_info import DeepLinkInfo
from .device_token import (
    DeviceToken,
    DeviceTokenApplePush,
    DeviceTokenApplePushVoIP,
    DeviceTokenBlackBerryPush,
    DeviceTokenFirebaseCloudMessaging,
    DeviceTokenMicrosoftPush,
    DeviceTokenMicrosoftPushVoIP,
    DeviceTokenSimplePush,
    DeviceTokenTizenPush,
    DeviceTokenUbuntuPush,
    DeviceTokenWebPush,
    DeviceTokenWindowsPush,
)
from .dice_stickers import (
    DiceStickers,
    DiceStickersRegular,
    DiceStickersSlotMachine,
)
from .document import Document
from .draft_message import DraftMessage
from .email_address_authentication_code_info import EmailAddressAuthenticationCodeInfo
from .emojis import Emojis
from .encrypted_credentials import EncryptedCredentials
from .encrypted_passport_element import EncryptedPassportElement
from .error import Error
from .file import File
from .file_part import FilePart
from .file_type import (
    FileType,
    FileTypeAnimation,
    FileTypeAudio,
    FileTypeDocument,
    FileTypeNone,
    FileTypePhoto,
    FileTypeProfilePhoto,
    FileTypeSecret,
    FileTypeSecretThumbnail,
    FileTypeSecure,
    FileTypeSticker,
    FileTypeThumbnail,
    FileTypeUnknown,
    FileTypeVideo,
    FileTypeVideoNote,
    FileTypeVoiceNote,
    FileTypeWallpaper,
)
from .formatted_text import FormattedText
from .found_messages import FoundMessages
from .game import Game
from .game_high_score import GameHighScore
from .game_high_scores import GameHighScores
from .group_call import GroupCall
from .group_call_id import GroupCallId
from .group_call_participant import GroupCallParticipant
from .group_call_participant_video_info import GroupCallParticipantVideoInfo
from .group_call_recent_speaker import GroupCallRecentSpeaker
from .group_call_video_source_group import GroupCallVideoSourceGroup
from .hashtags import Hashtags
from .http_url import HttpUrl
from .identity_document import IdentityDocument
from .imported_contacts import ImportedContacts
from .inline_keyboard_button import InlineKeyboardButton
from .inline_keyboard_button_type import (
    InlineKeyboardButtonType,
    InlineKeyboardButtonTypeBuy,
    InlineKeyboardButtonTypeCallback,
    InlineKeyboardButtonTypeCallbackGame,
    InlineKeyboardButtonTypeCallbackWithPassword,
    InlineKeyboardButtonTypeLoginUrl,
    InlineKeyboardButtonTypeSwitchInline,
    InlineKeyboardButtonTypeUrl,
)
from .inline_query_result import (
    InlineQueryResult,
    InlineQueryResultAnimation,
    InlineQueryResultArticle,
    InlineQueryResultAudio,
    InlineQueryResultContact,
    InlineQueryResultDocument,
    InlineQueryResultGame,
    InlineQueryResultLocation,
    InlineQueryResultPhoto,
    InlineQueryResultSticker,
    InlineQueryResultVenue,
    InlineQueryResultVideo,
    InlineQueryResultVoiceNote,
)
from .inline_query_results import InlineQueryResults
from .input_background import (
    InputBackground,
    InputBackgroundLocal,
    InputBackgroundRemote,
)
from .input_chat_photo import (
    InputChatPhoto,
    InputChatPhotoAnimation,
    InputChatPhotoPrevious,
    InputChatPhotoStatic,
)
from .input_credentials import (
    InputCredentials,
    InputCredentialsApplePay,
    InputCredentialsGooglePay,
    InputCredentialsNew,
    InputCredentialsSaved,
)
from .input_file import (
    InputFile,
    InputFileGenerated,
    InputFileId,
    InputFileLocal,
    InputFileRemote,
)
from .input_identity_document import InputIdentityDocument
from .input_inline_query_result import (
    InputInlineQueryResult,
    InputInlineQueryResultAnimation,
    InputInlineQueryResultArticle,
    InputInlineQueryResultAudio,
    InputInlineQueryResultContact,
    InputInlineQueryResultDocument,
    InputInlineQueryResultGame,
    InputInlineQueryResultLocation,
    InputInlineQueryResultPhoto,
    InputInlineQueryResultSticker,
    InputInlineQueryResultVenue,
    InputInlineQueryResultVideo,
    InputInlineQueryResultVoiceNote,
)
from .input_message_content import (
    InputMessageAnimation,
    InputMessageAudio,
    InputMessageContact,
    InputMessageContent,
    InputMessageDice,
    InputMessageDocument,
    InputMessageForwarded,
    InputMessageGame,
    InputMessageInvoice,
    InputMessageLocation,
    InputMessagePhoto,
    InputMessagePoll,
    InputMessageSticker,
    InputMessageText,
    InputMessageVenue,
    InputMessageVideo,
    InputMessageVideoNote,
    InputMessageVoiceNote,
)
from .input_passport_element import (
    InputPassportElement,
    InputPassportElementAddress,
    InputPassportElementBankStatement,
    InputPassportElementDriverLicense,
    InputPassportElementEmailAddress,
    InputPassportElementIdentityCard,
    InputPassportElementInternalPassport,
    InputPassportElementPassport,
    InputPassportElementPassportRegistration,
    InputPassportElementPersonalDetails,
    InputPassportElementPhoneNumber,
    InputPassportElementRentalAgreement,
    InputPassportElementTemporaryRegistration,
    InputPassportElementUtilityBill,
)
from .input_passport_element_error import InputPassportElementError
from .input_passport_element_error_source import (
    InputPassportElementErrorSource,
    InputPassportElementErrorSourceDataField,
    InputPassportElementErrorSourceFile,
    InputPassportElementErrorSourceFiles,
    InputPassportElementErrorSourceFrontSide,
    InputPassportElementErrorSourceReverseSide,
    InputPassportElementErrorSourceSelfie,
    InputPassportElementErrorSourceTranslationFile,
    InputPassportElementErrorSourceTranslationFiles,
    InputPassportElementErrorSourceUnspecified,
)
from .input_personal_document import InputPersonalDocument
from .input_sticker import (
    InputSticker,
    InputStickerAnimated,
    InputStickerStatic,
)
from .input_thumbnail import InputThumbnail
from .internal_link_type import (
    InternalLinkType,
    InternalLinkTypeActiveSessions,
    InternalLinkTypeAuthenticationCode,
    InternalLinkTypeBackground,
    InternalLinkTypeBotStart,
    InternalLinkTypeBotStartInGroup,
    InternalLinkTypeChangePhoneNumber,
    InternalLinkTypeChatInvite,
    InternalLinkTypeFilterSettings,
    InternalLinkTypeGame,
    InternalLinkTypeLanguagePack,
    InternalLinkTypeMessage,
    InternalLinkTypeMessageDraft,
    InternalLinkTypePassportDataRequest,
    InternalLinkTypePhoneNumberConfirmation,
    InternalLinkTypeProxy,
    InternalLinkTypePublicChat,
    InternalLinkTypeQrCodeAuthentication,
    InternalLinkTypeSettings,
    InternalLinkTypeStickerSet,
    InternalLinkTypeTheme,
    InternalLinkTypeThemeSettings,
    InternalLinkTypeUnknownDeepLink,
    InternalLinkTypeVoiceChat,
)
from .invoice import Invoice
from .json_value import (
    JsonObjectMember,
    JsonValue,
    JsonValueArray,
    JsonValueBoolean,
    JsonValueNull,
    JsonValueNumber,
    JsonValueObject,
    JsonValueString,
)
from .keyboard_button import KeyboardButton
from .keyboard_button_type import (
    KeyboardButtonType,
    KeyboardButtonTypeRequestLocation,
    KeyboardButtonTypeRequestPhoneNumber,
    KeyboardButtonTypeRequestPoll,
    KeyboardButtonTypeText,
)
from .labeled_price_part import LabeledPricePart
from .language_pack_info import LanguagePackInfo
from .language_pack_string import LanguagePackString
from .language_pack_string_value import (
    LanguagePackStringValue,
    LanguagePackStringValueDeleted,
    LanguagePackStringValueOrdinary,
    LanguagePackStringValuePluralized,
)
from .language_pack_strings import LanguagePackStrings
from .local_file import LocalFile
from .localization_target_info import LocalizationTargetInfo
from .location import Location
from .log_stream import (
    LogStream,
    LogStreamDefault,
    LogStreamEmpty,
    LogStreamFile,
)
from .log_tags import LogTags
from .log_verbosity_level import LogVerbosityLevel
from .login_url_info import (
    LoginUrlInfo,
    LoginUrlInfoOpen,
    LoginUrlInfoRequestConfirmation,
)
from .mask_point import (
    MaskPoint,
    MaskPointChin,
    MaskPointEyes,
    MaskPointForehead,
    MaskPointMouth,
)
from .mask_position import MaskPosition
from .message import Message
from .message_content import (
    MessageAnimation,
    MessageAudio,
    MessageBasicGroupChatCreate,
    MessageCall,
    MessageChatAddMembers,
    MessageChatChangePhoto,
    MessageChatChangeTitle,
    MessageChatDeleteMember,
    MessageChatDeletePhoto,
    MessageChatJoinByLink,
    MessageChatSetTtl,
    MessageChatUpgradeFrom,
    MessageChatUpgradeTo,
    MessageContact,
    MessageContactRegistered,
    MessageContent,
    MessageCustomServiceAction,
    MessageDice,
    MessageDocument,
    MessageExpiredPhoto,
    MessageExpiredVideo,
    MessageGame,
    MessageGameScore,
    MessageInviteVoiceChatParticipants,
    MessageInvoice,
    MessageLocation,
    MessagePassportDataReceived,
    MessagePassportDataSent,
    MessagePaymentSuccessful,
    MessagePaymentSuccessfulBot,
    MessagePhoto,
    MessagePinMessage,
    MessagePoll,
    MessageProximityAlertTriggered,
    MessageScreenshotTaken,
    MessageSticker,
    MessageSupergroupChatCreate,
    MessageText,
    MessageUnsupported,
    MessageVenue,
    MessageVideo,
    MessageVideoNote,
    MessageVoiceChatEnded,
    MessageVoiceChatScheduled,
    MessageVoiceChatStarted,
    MessageVoiceNote,
    MessageWebsiteConnected,
)
from .message_copy_options import MessageCopyOptions
from .message_file_type import (
    MessageFileType,
    MessageFileTypeGroup,
    MessageFileTypePrivate,
    MessageFileTypeUnknown,
)
from .message_forward_info import MessageForwardInfo
from .message_forward_origin import (
    MessageForwardOrigin,
    MessageForwardOriginChannel,
    MessageForwardOriginChat,
    MessageForwardOriginHiddenUser,
    MessageForwardOriginMessageImport,
    MessageForwardOriginUser,
)
from .message_interaction_info import MessageInteractionInfo
from .message_link import MessageLink
from .message_link_info import MessageLinkInfo
from .message_reply_info import MessageReplyInfo
from .message_scheduling_state import (
    MessageSchedulingState,
    MessageSchedulingStateSendAtDate,
    MessageSchedulingStateSendWhenOnline,
)
from .message_send_options import MessageSendOptions
from .message_sender import (
    MessageSender,
    MessageSenderChat,
    MessageSenderUser,
)
from .message_senders import MessageSenders
from .message_sending_state import (
    MessageSendingState,
    MessageSendingStateFailed,
    MessageSendingStatePending,
)
from .message_statistics import MessageStatistics
from .message_thread_info import MessageThreadInfo
from .messages import Messages
from .minithumbnail import Minithumbnail
from .network_statistics import NetworkStatistics
from .network_statistics_entry import (
    NetworkStatisticsEntry,
    NetworkStatisticsEntryCall,
    NetworkStatisticsEntryFile,
)
from .network_type import (
    NetworkType,
    NetworkTypeMobile,
    NetworkTypeMobileRoaming,
    NetworkTypeNone,
    NetworkTypeOther,
    NetworkTypeWiFi,
)
from .notification import Notification
from .notification_group import NotificationGroup
from .notification_group_type import (
    NotificationGroupType,
    NotificationGroupTypeCalls,
    NotificationGroupTypeMentions,
    NotificationGroupTypeMessages,
    NotificationGroupTypeSecretChat,
)
from .notification_settings_scope import (
    NotificationSettingsScope,
    NotificationSettingsScopeChannelChats,
    NotificationSettingsScopeGroupChats,
    NotificationSettingsScopePrivateChats,
)
from .notification_type import (
    NotificationType,
    NotificationTypeNewCall,
    NotificationTypeNewMessage,
    NotificationTypeNewPushMessage,
    NotificationTypeNewSecretChat,
)
from .ok import Ok
from .option_value import (
    OptionValue,
    OptionValueBoolean,
    OptionValueEmpty,
    OptionValueInteger,
    OptionValueString,
)
from .order_info import OrderInfo
from .page_block import (
    PageBlock,
    PageBlockAnchor,
    PageBlockAnimation,
    PageBlockAudio,
    PageBlockAuthorDate,
    PageBlockBlockQuote,
    PageBlockChatLink,
    PageBlockCollage,
    PageBlockCover,
    PageBlockDetails,
    PageBlockDivider,
    PageBlockEmbedded,
    PageBlockEmbeddedPost,
    PageBlockFooter,
    PageBlockHeader,
    PageBlockKicker,
    PageBlockList,
    PageBlockListItem,
    PageBlockMap,
    PageBlockParagraph,
    PageBlockPhoto,
    PageBlockPreformatted,
    PageBlockPullQuote,
    PageBlockRelatedArticles,
    PageBlockSlideshow,
    PageBlockSubheader,
    PageBlockSubtitle,
    PageBlockTable,
    PageBlockTitle,
    PageBlockVideo,
    PageBlockVoiceNote,
)
from .page_block_caption import PageBlockCaption
from .page_block_horizontal_alignment import (
    PageBlockHorizontalAlignment,
    PageBlockHorizontalAlignmentCenter,
    PageBlockHorizontalAlignmentLeft,
    PageBlockHorizontalAlignmentRight,
)
from .page_block_related_article import PageBlockRelatedArticle
from .page_block_table_cell import PageBlockTableCell
from .page_block_vertical_alignment import (
    PageBlockVerticalAlignment,
    PageBlockVerticalAlignmentBottom,
    PageBlockVerticalAlignmentMiddle,
    PageBlockVerticalAlignmentTop,
)
from .passport_authorization_form import PassportAuthorizationForm
from .passport_element import (
    PassportElement,
    PassportElementAddress,
    PassportElementBankStatement,
    PassportElementDriverLicense,
    PassportElementEmailAddress,
    PassportElementIdentityCard,
    PassportElementInternalPassport,
    PassportElementPassport,
    PassportElementPassportRegistration,
    PassportElementPersonalDetails,
    PassportElementPhoneNumber,
    PassportElementRentalAgreement,
    PassportElementTemporaryRegistration,
    PassportElementUtilityBill,
)
from .passport_element_error import PassportElementError
from .passport_element_error_source import (
    PassportElementErrorSource,
    PassportElementErrorSourceDataField,
    PassportElementErrorSourceFile,
    PassportElementErrorSourceFiles,
    PassportElementErrorSourceFrontSide,
    PassportElementErrorSourceReverseSide,
    PassportElementErrorSourceSelfie,
    PassportElementErrorSourceTranslationFile,
    PassportElementErrorSourceTranslationFiles,
    PassportElementErrorSourceUnspecified,
)
from .passport_element_type import (
    PassportElementType,
    PassportElementTypeAddress,
    PassportElementTypeBankStatement,
    PassportElementTypeDriverLicense,
    PassportElementTypeEmailAddress,
    PassportElementTypeIdentityCard,
    PassportElementTypeInternalPassport,
    PassportElementTypePassport,
    PassportElementTypePassportRegistration,
    PassportElementTypePersonalDetails,
    PassportElementTypePhoneNumber,
    PassportElementTypeRentalAgreement,
    PassportElementTypeTemporaryRegistration,
    PassportElementTypeUtilityBill,
)
from .passport_elements import PassportElements
from .passport_elements_with_errors import PassportElementsWithErrors
from .passport_required_element import PassportRequiredElement
from .passport_suitable_element import PassportSuitableElement
from .password_state import PasswordState
from .payment_form import PaymentForm
from .payment_form_theme import PaymentFormTheme
from .payment_receipt import PaymentReceipt
from .payment_result import PaymentResult
from .payments_provider_stripe import PaymentsProviderStripe
from .personal_details import PersonalDetails
from .personal_document import PersonalDocument
from .phone_number_authentication_settings import PhoneNumberAuthenticationSettings
from .phone_number_info import PhoneNumberInfo
from .photo import Photo
from .photo_size import PhotoSize
from .point import Point
from .poll import Poll
from .poll_option import PollOption
from .poll_type import (
    PollType,
    PollTypeQuiz,
    PollTypeRegular,
)
from .profile_photo import ProfilePhoto
from .proxies import Proxies
from .proxy import Proxy
from .proxy_type import (
    ProxyType,
    ProxyTypeHttp,
    ProxyTypeMtproto,
    ProxyTypeSocks5,
)
from .public_chat_type import (
    PublicChatType,
    PublicChatTypeHasUsername,
    PublicChatTypeIsLocationBased,
)
from .push_message_content import (
    PushMessageContent,
    PushMessageContentAnimation,
    PushMessageContentAudio,
    PushMessageContentBasicGroupChatCreate,
    PushMessageContentChatAddMembers,
    PushMessageContentChatChangePhoto,
    PushMessageContentChatChangeTitle,
    PushMessageContentChatDeleteMember,
    PushMessageContentChatJoinByLink,
    PushMessageContentContact,
    PushMessageContentContactRegistered,
    PushMessageContentDocument,
    PushMessageContentGame,
    PushMessageContentGameScore,
    PushMessageContentHidden,
    PushMessageContentInvoice,
    PushMessageContentLocation,
    PushMessageContentMediaAlbum,
    PushMessageContentMessageForwards,
    PushMessageContentPhoto,
    PushMessageContentPoll,
    PushMessageContentScreenshotTaken,
    PushMessageContentSticker,
    PushMessageContentText,
    PushMessageContentVideo,
    PushMessageContentVideoNote,
    PushMessageContentVoiceNote,
)
from .push_receiver_id import PushReceiverId
from .recommended_chat_filter import RecommendedChatFilter
from .recommended_chat_filters import RecommendedChatFilters
from .recovery_email_address import RecoveryEmailAddress
from .remote_file import RemoteFile
from .reply_markup import (
    ReplyMarkup,
    ReplyMarkupForceReply,
    ReplyMarkupInlineKeyboard,
    ReplyMarkupRemoveKeyboard,
    ReplyMarkupShowKeyboard,
)
from .reset_password_result import (
    ResetPasswordResult,
    ResetPasswordResultDeclined,
    ResetPasswordResultOk,
    ResetPasswordResultPending,
)
from .rich_text import (
    RichText,
    RichTextAnchor,
    RichTextAnchorLink,
    RichTextBold,
    RichTextEmailAddress,
    RichTextFixed,
    RichTextIcon,
    RichTextItalic,
    RichTextMarked,
    RichTextPhoneNumber,
    RichTextPlain,
    RichTextReference,
    RichTextStrikethrough,
    RichTextSubscript,
    RichTextSuperscript,
    RichTextUnderline,
    RichTextUrl,
    RichTexts,
)
from .saved_credentials import SavedCredentials
from .scope_notification_settings import ScopeNotificationSettings
from .search_messages_filter import (
    SearchMessagesFilter,
    SearchMessagesFilterAnimation,
    SearchMessagesFilterAudio,
    SearchMessagesFilterCall,
    SearchMessagesFilterChatPhoto,
    SearchMessagesFilterDocument,
    SearchMessagesFilterEmpty,
    SearchMessagesFilterFailedToSend,
    SearchMessagesFilterMention,
    SearchMessagesFilterMissedCall,
    SearchMessagesFilterPhoto,
    SearchMessagesFilterPhotoAndVideo,
    SearchMessagesFilterPinned,
    SearchMessagesFilterUnreadMention,
    SearchMessagesFilterUrl,
    SearchMessagesFilterVideo,
    SearchMessagesFilterVideoNote,
    SearchMessagesFilterVoiceAndVideoNote,
    SearchMessagesFilterVoiceNote,
)
from .seconds import Seconds
from .secret_chat import SecretChat
from .secret_chat_state import (
    SecretChatState,
    SecretChatStateClosed,
    SecretChatStatePending,
    SecretChatStateReady,
)
from .session import Session
from .sessions import Sessions
from .shipping_option import ShippingOption
from .statistical_graph import (
    StatisticalGraph,
    StatisticalGraphAsync,
    StatisticalGraphData,
    StatisticalGraphError,
)
from .statistical_value import StatisticalValue
from .sticker import Sticker
from .sticker_set import StickerSet
from .sticker_set_info import StickerSetInfo
from .sticker_sets import StickerSets
from .stickers import Stickers
from .storage_statistics import StorageStatistics
from .storage_statistics_by_chat import StorageStatisticsByChat
from .storage_statistics_by_file_type import StorageStatisticsByFileType
from .storage_statistics_fast import StorageStatisticsFast
from .suggested_action import (
    SuggestedAction,
    SuggestedActionCheckPassword,
    SuggestedActionCheckPhoneNumber,
    SuggestedActionConvertToBroadcastGroup,
    SuggestedActionEnableArchiveAndMuteNewChats,
    SuggestedActionSeeTicksHint,
)
from .supergroup import Supergroup
from .supergroup_full_info import SupergroupFullInfo
from .supergroup_members_filter import (
    SupergroupMembersFilter,
    SupergroupMembersFilterAdministrators,
    SupergroupMembersFilterBanned,
    SupergroupMembersFilterBots,
    SupergroupMembersFilterContacts,
    SupergroupMembersFilterMention,
    SupergroupMembersFilterRecent,
    SupergroupMembersFilterRestricted,
    SupergroupMembersFilterSearch,
)
from .t_me_url import TMeUrl
from .t_me_url_type import (
    TMeUrlType,
    TMeUrlTypeChatInvite,
    TMeUrlTypeStickerSet,
    TMeUrlTypeSupergroup,
    TMeUrlTypeUser,
)
from .t_me_urls import TMeUrls
from .tdlib_parameters import TdlibParameters
from .temporary_password_state import TemporaryPasswordState
from .terms_of_service import TermsOfService
from .test_bytes import TestBytes
from .test_int import TestInt
from .test_string import TestString
from .test_vector_int import TestVectorInt
from .test_vector_int_object import TestVectorIntObject
from .test_vector_string import TestVectorString
from .test_vector_string_object import TestVectorStringObject
from .text import Text
from .text_entities import TextEntities
from .text_entity import TextEntity
from .text_entity_type import (
    TextEntityType,
    TextEntityTypeBankCardNumber,
    TextEntityTypeBold,
    TextEntityTypeBotCommand,
    TextEntityTypeCashtag,
    TextEntityTypeCode,
    TextEntityTypeEmailAddress,
    TextEntityTypeHashtag,
    TextEntityTypeItalic,
    TextEntityTypeMention,
    TextEntityTypeMentionName,
    TextEntityTypePhoneNumber,
    TextEntityTypePre,
    TextEntityTypePreCode,
    TextEntityTypeStrikethrough,
    TextEntityTypeTextUrl,
    TextEntityTypeUnderline,
    TextEntityTypeUrl,
)
from .text_parse_mode import (
    TextParseMode,
    TextParseModeHTML,
    TextParseModeMarkdown,
)
from .thumbnail import Thumbnail
from .thumbnail_format import (
    ThumbnailFormat,
    ThumbnailFormatGif,
    ThumbnailFormatJpeg,
    ThumbnailFormatMpeg4,
    ThumbnailFormatPng,
    ThumbnailFormatTgs,
    ThumbnailFormatWebp,
)
from .top_chat_category import (
    TopChatCategory,
    TopChatCategoryBots,
    TopChatCategoryCalls,
    TopChatCategoryChannels,
    TopChatCategoryForwardChats,
    TopChatCategoryGroups,
    TopChatCategoryInlineBots,
    TopChatCategoryUsers,
)
from .update import (
    Update,
    UpdateActiveNotifications,
    UpdateAnimationSearchParameters,
    UpdateAuthorizationState,
    UpdateBasicGroup,
    UpdateBasicGroupFullInfo,
    UpdateCall,
    UpdateChatActionBar,
    UpdateChatDefaultDisableNotification,
    UpdateChatDraftMessage,
    UpdateChatFilters,
    UpdateChatHasScheduledMessages,
    UpdateChatIsBlocked,
    UpdateChatIsMarkedAsUnread,
    UpdateChatLastMessage,
    UpdateChatMember,
    UpdateChatMessageTtlSetting,
    UpdateChatNotificationSettings,
    UpdateChatOnlineMemberCount,
    UpdateChatPermissions,
    UpdateChatPhoto,
    UpdateChatPosition,
    UpdateChatReadInbox,
    UpdateChatReadOutbox,
    UpdateChatReplyMarkup,
    UpdateChatTitle,
    UpdateChatUnreadMentionCount,
    UpdateChatVoiceChat,
    UpdateConnectionState,
    UpdateDeleteMessages,
    UpdateDiceEmojis,
    UpdateFavoriteStickers,
    UpdateFile,
    UpdateFileGenerationStart,
    UpdateFileGenerationStop,
    UpdateGroupCall,
    UpdateGroupCallParticipant,
    UpdateHavePendingNotifications,
    UpdateInstalledStickerSets,
    UpdateLanguagePackStrings,
    UpdateMessageContent,
    UpdateMessageContentOpened,
    UpdateMessageEdited,
    UpdateMessageInteractionInfo,
    UpdateMessageIsPinned,
    UpdateMessageLiveLocationViewed,
    UpdateMessageMentionRead,
    UpdateMessageSendAcknowledged,
    UpdateMessageSendFailed,
    UpdateMessageSendSucceeded,
    UpdateNewCallSignalingData,
    UpdateNewCallbackQuery,
    UpdateNewChat,
    UpdateNewChosenInlineResult,
    UpdateNewCustomEvent,
    UpdateNewCustomQuery,
    UpdateNewInlineCallbackQuery,
    UpdateNewInlineQuery,
    UpdateNewMessage,
    UpdateNewPreCheckoutQuery,
    UpdateNewShippingQuery,
    UpdateNotification,
    UpdateNotificationGroup,
    UpdateOption,
    UpdatePoll,
    UpdatePollAnswer,
    UpdateRecentStickers,
    UpdateSavedAnimations,
    UpdateScopeNotificationSettings,
    UpdateSecretChat,
    UpdateSelectedBackground,
    UpdateServiceNotification,
    UpdateStickerSet,
    UpdateSuggestedActions,
    UpdateSupergroup,
    UpdateSupergroupFullInfo,
    UpdateTermsOfService,
    UpdateTrendingStickerSets,
    UpdateUnreadChatCount,
    UpdateUnreadMessageCount,
    UpdateUser,
    UpdateUserChatAction,
    UpdateUserFullInfo,
    UpdateUserPrivacySettingRules,
    UpdateUserStatus,
    UpdateUsersNearby,
)
from .updates import Updates
from .user import User
from .user_full_info import UserFullInfo
from .user_privacy_setting import (
    UserPrivacySetting,
    UserPrivacySettingAllowCalls,
    UserPrivacySettingAllowChatInvites,
    UserPrivacySettingAllowFindingByPhoneNumber,
    UserPrivacySettingAllowPeerToPeerCalls,
    UserPrivacySettingShowLinkInForwardedMessages,
    UserPrivacySettingShowPhoneNumber,
    UserPrivacySettingShowProfilePhoto,
    UserPrivacySettingShowStatus,
)
from .user_privacy_setting_rule import (
    UserPrivacySettingRule,
    UserPrivacySettingRuleAllowAll,
    UserPrivacySettingRuleAllowChatMembers,
    UserPrivacySettingRuleAllowContacts,
    UserPrivacySettingRuleAllowUsers,
    UserPrivacySettingRuleRestrictAll,
    UserPrivacySettingRuleRestrictChatMembers,
    UserPrivacySettingRuleRestrictContacts,
    UserPrivacySettingRuleRestrictUsers,
)
from .user_privacy_setting_rules import UserPrivacySettingRules
from .user_status import (
    UserStatus,
    UserStatusEmpty,
    UserStatusLastMonth,
    UserStatusLastWeek,
    UserStatusOffline,
    UserStatusOnline,
    UserStatusRecently,
)
from .user_type import (
    UserType,
    UserTypeBot,
    UserTypeDeleted,
    UserTypeRegular,
    UserTypeUnknown,
)
from .users import Users
from .validated_order_info import ValidatedOrderInfo
from .vector_path_command import (
    VectorPathCommand,
    VectorPathCommandCubicBezierCurve,
    VectorPathCommandLine,
)
from .venue import Venue
from .video import Video
from .video_note import VideoNote
from .voice_chat import VoiceChat
from .voice_note import VoiceNote
from .web_page import WebPage
from .web_page_instant_view import WebPageInstantView

__all__ = [
    "AccountTtl",
    "Address",
    "AnimatedChatPhoto",
    "Animation",
    "Animations",
    "Audio",
    "AuthenticationCodeInfo",
    "AuthenticationCodeType",
    "AuthenticationCodeTypeCall",
    "AuthenticationCodeTypeFlashCall",
    "AuthenticationCodeTypeSms",
    "AuthenticationCodeTypeTelegramMessage",
    "AuthorizationState",
    "AuthorizationStateClosed",
    "AuthorizationStateClosing",
    "AuthorizationStateLoggingOut",
    "AuthorizationStateReady",
    "AuthorizationStateWaitCode",
    "AuthorizationStateWaitEncryptionKey",
    "AuthorizationStateWaitOtherDeviceConfirmation",
    "AuthorizationStateWaitPassword",
    "AuthorizationStateWaitPhoneNumber",
    "AuthorizationStateWaitRegistration",
    "AuthorizationStateWaitTdlibParameters",
    "AutoDownloadSettings",
    "AutoDownloadSettingsPresets",
    "Background",
    "BackgroundFill",
    "BackgroundFillFreeformGradient",
    "BackgroundFillGradient",
    "BackgroundFillSolid",
    "BackgroundType",
    "BackgroundTypeFill",
    "BackgroundTypePattern",
    "BackgroundTypeWallpaper",
    "Backgrounds",
    "BankCardActionOpenUrl",
    "BankCardInfo",
    "BasicGroup",
    "BasicGroupFullInfo",
    "BotCommand",
    "BotCommandScope",
    "BotCommandScopeAllChatAdministrators",
    "BotCommandScopeAllGroupChats",
    "BotCommandScopeAllPrivateChats",
    "BotCommandScopeChat",
    "BotCommandScopeChatAdministrators",
    "BotCommandScopeChatMember",
    "BotCommandScopeDefault",
    "BotCommands",
    "Call",
    "CallDiscardReason",
    "CallDiscardReasonDeclined",
    "CallDiscardReasonDisconnected",
    "CallDiscardReasonEmpty",
    "CallDiscardReasonHungUp",
    "CallDiscardReasonMissed",
    "CallId",
    "CallProblem",
    "CallProblemDistortedSpeech",
    "CallProblemDistortedVideo",
    "CallProblemDropped",
    "CallProblemEcho",
    "CallProblemInterruptions",
    "CallProblemNoise",
    "CallProblemPixelatedVideo",
    "CallProblemSilentLocal",
    "CallProblemSilentRemote",
    "CallProtocol",
    "CallServer",
    "CallServerType",
    "CallServerTypeTelegramReflector",
    "CallServerTypeWebrtc",
    "CallState",
    "CallStateDiscarded",
    "CallStateError",
    "CallStateExchangingKeys",
    "CallStateHangingUp",
    "CallStatePending",
    "CallStateReady",
    "CallbackQueryAnswer",
    "CallbackQueryPayload",
    "CallbackQueryPayloadData",
    "CallbackQueryPayloadDataWithPassword",
    "CallbackQueryPayloadGame",
    "CanTransferOwnershipResult",
    "CanTransferOwnershipResultOk",
    "CanTransferOwnershipResultPasswordNeeded",
    "CanTransferOwnershipResultPasswordTooFresh",
    "CanTransferOwnershipResultSessionTooFresh",
    "Chat",
    "ChatAction",
    "ChatActionCancel",
    "ChatActionChoosingContact",
    "ChatActionChoosingLocation",
    "ChatActionRecordingVideo",
    "ChatActionRecordingVideoNote",
    "ChatActionRecordingVoiceNote",
    "ChatActionStartPlayingGame",
    "ChatActionTyping",
    "ChatActionUploadingDocument",
    "ChatActionUploadingPhoto",
    "ChatActionUploadingVideo",
    "ChatActionUploadingVideoNote",
    "ChatActionUploadingVoiceNote",
    "ChatActionBar",
    "ChatActionBarAddContact",
    "ChatActionBarInviteMembers",
    "ChatActionBarReportAddBlock",
    "ChatActionBarReportSpam",
    "ChatActionBarReportUnrelatedLocation",
    "ChatActionBarSharePhoneNumber",
    "ChatAdministrator",
    "ChatAdministrators",
    "ChatEvent",
    "ChatEventAction",
    "ChatEventDescriptionChanged",
    "ChatEventInviteLinkDeleted",
    "ChatEventInviteLinkEdited",
    "ChatEventInviteLinkRevoked",
    "ChatEventInvitesToggled",
    "ChatEventIsAllHistoryAvailableToggled",
    "ChatEventLinkedChatChanged",
    "ChatEventLocationChanged",
    "ChatEventMemberInvited",
    "ChatEventMemberJoined",
    "ChatEventMemberJoinedByInviteLink",
    "ChatEventMemberLeft",
    "ChatEventMemberPromoted",
    "ChatEventMemberRestricted",
    "ChatEventMessageDeleted",
    "ChatEventMessageEdited",
    "ChatEventMessagePinned",
    "ChatEventMessageTtlSettingChanged",
    "ChatEventMessageUnpinned",
    "ChatEventPermissionsChanged",
    "ChatEventPhotoChanged",
    "ChatEventPollStopped",
    "ChatEventSignMessagesToggled",
    "ChatEventSlowModeDelayChanged",
    "ChatEventStickerSetChanged",
    "ChatEventTitleChanged",
    "ChatEventUsernameChanged",
    "ChatEventVoiceChatCreated",
    "ChatEventVoiceChatDiscarded",
    "ChatEventVoiceChatMuteNewParticipantsToggled",
    "ChatEventVoiceChatParticipantIsMutedToggled",
    "ChatEventVoiceChatParticipantVolumeLevelChanged",
    "ChatEventLogFilters",
    "ChatEvents",
    "ChatFilter",
    "ChatFilterInfo",
    "ChatInviteLink",
    "ChatInviteLinkCount",
    "ChatInviteLinkCounts",
    "ChatInviteLinkInfo",
    "ChatInviteLinkMember",
    "ChatInviteLinkMembers",
    "ChatInviteLinks",
    "ChatList",
    "ChatListArchive",
    "ChatListFilter",
    "ChatListMain",
    "ChatLists",
    "ChatLocation",
    "ChatMember",
    "ChatMemberStatus",
    "ChatMemberStatusAdministrator",
    "ChatMemberStatusBanned",
    "ChatMemberStatusCreator",
    "ChatMemberStatusLeft",
    "ChatMemberStatusMember",
    "ChatMemberStatusRestricted",
    "ChatMembers",
    "ChatMembersFilter",
    "ChatMembersFilterAdministrators",
    "ChatMembersFilterBanned",
    "ChatMembersFilterBots",
    "ChatMembersFilterContacts",
    "ChatMembersFilterMembers",
    "ChatMembersFilterMention",
    "ChatMembersFilterRestricted",
    "ChatNearby",
    "ChatNotificationSettings",
    "ChatPermissions",
    "ChatPhoto",
    "ChatPhotoInfo",
    "ChatPhotos",
    "ChatPosition",
    "ChatReportReason",
    "ChatReportReasonChildAbuse",
    "ChatReportReasonCopyright",
    "ChatReportReasonCustom",
    "ChatReportReasonFake",
    "ChatReportReasonPornography",
    "ChatReportReasonSpam",
    "ChatReportReasonUnrelatedLocation",
    "ChatReportReasonViolence",
    "ChatSource",
    "ChatSourceMtprotoProxy",
    "ChatSourcePublicServiceAnnouncement",
    "ChatStatistics",
    "ChatStatisticsChannel",
    "ChatStatisticsSupergroup",
    "ChatStatisticsAdministratorActionsInfo",
    "ChatStatisticsInviterInfo",
    "ChatStatisticsMessageInteractionInfo",
    "ChatStatisticsMessageSenderInfo",
    "ChatType",
    "ChatTypeBasicGroup",
    "ChatTypePrivate",
    "ChatTypeSecret",
    "ChatTypeSupergroup",
    "Chats",
    "ChatsNearby",
    "CheckChatUsernameResult",
    "CheckChatUsernameResultOk",
    "CheckChatUsernameResultPublicChatsTooMuch",
    "CheckChatUsernameResultPublicGroupsUnavailable",
    "CheckChatUsernameResultUsernameInvalid",
    "CheckChatUsernameResultUsernameOccupied",
    "CheckStickerSetNameResult",
    "CheckStickerSetNameResultNameInvalid",
    "CheckStickerSetNameResultNameOccupied",
    "CheckStickerSetNameResultOk",
    "ClosedVectorPath",
    "ConnectedWebsite",
    "ConnectedWebsites",
    "ConnectionState",
    "ConnectionStateConnecting",
    "ConnectionStateConnectingToProxy",
    "ConnectionStateReady",
    "ConnectionStateUpdating",
    "ConnectionStateWaitingForNetwork",
    "Contact",
    "Count",
    "Countries",
    "CountryInfo",
    "CustomRequestResult",
    "DatabaseStatistics",
    "Date",
    "DateRange",
    "DatedFile",
    "DeepLinkInfo",
    "DeviceToken",
    "DeviceTokenApplePush",
    "DeviceTokenApplePushVoIP",
    "DeviceTokenBlackBerryPush",
    "DeviceTokenFirebaseCloudMessaging",
    "DeviceTokenMicrosoftPush",
    "DeviceTokenMicrosoftPushVoIP",
    "DeviceTokenSimplePush",
    "DeviceTokenTizenPush",
    "DeviceTokenUbuntuPush",
    "DeviceTokenWebPush",
    "DeviceTokenWindowsPush",
    "DiceStickers",
    "DiceStickersRegular",
    "DiceStickersSlotMachine",
    "Document",
    "DraftMessage",
    "EmailAddressAuthenticationCodeInfo",
    "Emojis",
    "EncryptedCredentials",
    "EncryptedPassportElement",
    "Error",
    "File",
    "FilePart",
    "FileType",
    "FileTypeAnimation",
    "FileTypeAudio",
    "FileTypeDocument",
    "FileTypeNone",
    "FileTypePhoto",
    "FileTypeProfilePhoto",
    "FileTypeSecret",
    "FileTypeSecretThumbnail",
    "FileTypeSecure",
    "FileTypeSticker",
    "FileTypeThumbnail",
    "FileTypeUnknown",
    "FileTypeVideo",
    "FileTypeVideoNote",
    "FileTypeVoiceNote",
    "FileTypeWallpaper",
    "FormattedText",
    "FoundMessages",
    "Game",
    "GameHighScore",
    "GameHighScores",
    "GroupCall",
    "GroupCallId",
    "GroupCallParticipant",
    "GroupCallParticipantVideoInfo",
    "GroupCallRecentSpeaker",
    "GroupCallVideoSourceGroup",
    "Hashtags",
    "HttpUrl",
    "IdentityDocument",
    "ImportedContacts",
    "InlineKeyboardButton",
    "InlineKeyboardButtonType",
    "InlineKeyboardButtonTypeBuy",
    "InlineKeyboardButtonTypeCallback",
    "InlineKeyboardButtonTypeCallbackGame",
    "InlineKeyboardButtonTypeCallbackWithPassword",
    "InlineKeyboardButtonTypeLoginUrl",
    "InlineKeyboardButtonTypeSwitchInline",
    "InlineKeyboardButtonTypeUrl",
    "InlineQueryResult",
    "InlineQueryResultAnimation",
    "InlineQueryResultArticle",
    "InlineQueryResultAudio",
    "InlineQueryResultContact",
    "InlineQueryResultDocument",
    "InlineQueryResultGame",
    "InlineQueryResultLocation",
    "InlineQueryResultPhoto",
    "InlineQueryResultSticker",
    "InlineQueryResultVenue",
    "InlineQueryResultVideo",
    "InlineQueryResultVoiceNote",
    "InlineQueryResults",
    "InputBackground",
    "InputBackgroundLocal",
    "InputBackgroundRemote",
    "InputChatPhoto",
    "InputChatPhotoAnimation",
    "InputChatPhotoPrevious",
    "InputChatPhotoStatic",
    "InputCredentials",
    "InputCredentialsApplePay",
    "InputCredentialsGooglePay",
    "InputCredentialsNew",
    "InputCredentialsSaved",
    "InputFile",
    "InputFileGenerated",
    "InputFileId",
    "InputFileLocal",
    "InputFileRemote",
    "InputIdentityDocument",
    "InputInlineQueryResult",
    "InputInlineQueryResultAnimation",
    "InputInlineQueryResultArticle",
    "InputInlineQueryResultAudio",
    "InputInlineQueryResultContact",
    "InputInlineQueryResultDocument",
    "InputInlineQueryResultGame",
    "InputInlineQueryResultLocation",
    "InputInlineQueryResultPhoto",
    "InputInlineQueryResultSticker",
    "InputInlineQueryResultVenue",
    "InputInlineQueryResultVideo",
    "InputInlineQueryResultVoiceNote",
    "InputMessageContent",
    "InputMessageAnimation",
    "InputMessageAudio",
    "InputMessageContact",
    "InputMessageDice",
    "InputMessageDocument",
    "InputMessageForwarded",
    "InputMessageGame",
    "InputMessageInvoice",
    "InputMessageLocation",
    "InputMessagePhoto",
    "InputMessagePoll",
    "InputMessageSticker",
    "InputMessageText",
    "InputMessageVenue",
    "InputMessageVideo",
    "InputMessageVideoNote",
    "InputMessageVoiceNote",
    "InputPassportElement",
    "InputPassportElementAddress",
    "InputPassportElementBankStatement",
    "InputPassportElementDriverLicense",
    "InputPassportElementEmailAddress",
    "InputPassportElementIdentityCard",
    "InputPassportElementInternalPassport",
    "InputPassportElementPassport",
    "InputPassportElementPassportRegistration",
    "InputPassportElementPersonalDetails",
    "InputPassportElementPhoneNumber",
    "InputPassportElementRentalAgreement",
    "InputPassportElementTemporaryRegistration",
    "InputPassportElementUtilityBill",
    "InputPassportElementError",
    "InputPassportElementErrorSource",
    "InputPassportElementErrorSourceDataField",
    "InputPassportElementErrorSourceFile",
    "InputPassportElementErrorSourceFiles",
    "InputPassportElementErrorSourceFrontSide",
    "InputPassportElementErrorSourceReverseSide",
    "InputPassportElementErrorSourceSelfie",
    "InputPassportElementErrorSourceTranslationFile",
    "InputPassportElementErrorSourceTranslationFiles",
    "InputPassportElementErrorSourceUnspecified",
    "InputPersonalDocument",
    "InputSticker",
    "InputStickerAnimated",
    "InputStickerStatic",
    "InputThumbnail",
    "InternalLinkType",
    "InternalLinkTypeActiveSessions",
    "InternalLinkTypeAuthenticationCode",
    "InternalLinkTypeBackground",
    "InternalLinkTypeBotStart",
    "InternalLinkTypeBotStartInGroup",
    "InternalLinkTypeChangePhoneNumber",
    "InternalLinkTypeChatInvite",
    "InternalLinkTypeFilterSettings",
    "InternalLinkTypeGame",
    "InternalLinkTypeLanguagePack",
    "InternalLinkTypeMessage",
    "InternalLinkTypeMessageDraft",
    "InternalLinkTypePassportDataRequest",
    "InternalLinkTypePhoneNumberConfirmation",
    "InternalLinkTypeProxy",
    "InternalLinkTypePublicChat",
    "InternalLinkTypeQrCodeAuthentication",
    "InternalLinkTypeSettings",
    "InternalLinkTypeStickerSet",
    "InternalLinkTypeTheme",
    "InternalLinkTypeThemeSettings",
    "InternalLinkTypeUnknownDeepLink",
    "InternalLinkTypeVoiceChat",
    "Invoice",
    "JsonValue",
    "JsonValueArray",
    "JsonValueBoolean",
    "JsonValueNull",
    "JsonValueNumber",
    "JsonValueObject",
    "JsonValueString",
    "JsonObjectMember",
    "KeyboardButton",
    "KeyboardButtonType",
    "KeyboardButtonTypeRequestLocation",
    "KeyboardButtonTypeRequestPhoneNumber",
    "KeyboardButtonTypeRequestPoll",
    "KeyboardButtonTypeText",
    "LabeledPricePart",
    "LanguagePackInfo",
    "LanguagePackString",
    "LanguagePackStringValue",
    "LanguagePackStringValueDeleted",
    "LanguagePackStringValueOrdinary",
    "LanguagePackStringValuePluralized",
    "LanguagePackStrings",
    "LocalFile",
    "LocalizationTargetInfo",
    "Location",
    "LogStream",
    "LogStreamDefault",
    "LogStreamEmpty",
    "LogStreamFile",
    "LogTags",
    "LogVerbosityLevel",
    "LoginUrlInfo",
    "LoginUrlInfoOpen",
    "LoginUrlInfoRequestConfirmation",
    "MaskPoint",
    "MaskPointChin",
    "MaskPointEyes",
    "MaskPointForehead",
    "MaskPointMouth",
    "MaskPosition",
    "Message",
    "MessageContent",
    "MessageAnimation",
    "MessageAudio",
    "MessageBasicGroupChatCreate",
    "MessageCall",
    "MessageChatAddMembers",
    "MessageChatChangePhoto",
    "MessageChatChangeTitle",
    "MessageChatDeleteMember",
    "MessageChatDeletePhoto",
    "MessageChatJoinByLink",
    "MessageChatSetTtl",
    "MessageChatUpgradeFrom",
    "MessageChatUpgradeTo",
    "MessageContact",
    "MessageContactRegistered",
    "MessageCustomServiceAction",
    "MessageDice",
    "MessageDocument",
    "MessageExpiredPhoto",
    "MessageExpiredVideo",
    "MessageGame",
    "MessageGameScore",
    "MessageInviteVoiceChatParticipants",
    "MessageInvoice",
    "MessageLocation",
    "MessagePassportDataReceived",
    "MessagePassportDataSent",
    "MessagePaymentSuccessful",
    "MessagePaymentSuccessfulBot",
    "MessagePhoto",
    "MessagePinMessage",
    "MessagePoll",
    "MessageProximityAlertTriggered",
    "MessageScreenshotTaken",
    "MessageSticker",
    "MessageSupergroupChatCreate",
    "MessageText",
    "MessageUnsupported",
    "MessageVenue",
    "MessageVideo",
    "MessageVideoNote",
    "MessageVoiceChatEnded",
    "MessageVoiceChatScheduled",
    "MessageVoiceChatStarted",
    "MessageVoiceNote",
    "MessageWebsiteConnected",
    "MessageCopyOptions",
    "MessageFileType",
    "MessageFileTypeGroup",
    "MessageFileTypePrivate",
    "MessageFileTypeUnknown",
    "MessageForwardInfo",
    "MessageForwardOrigin",
    "MessageForwardOriginChannel",
    "MessageForwardOriginChat",
    "MessageForwardOriginHiddenUser",
    "MessageForwardOriginMessageImport",
    "MessageForwardOriginUser",
    "MessageInteractionInfo",
    "MessageLink",
    "MessageLinkInfo",
    "MessageReplyInfo",
    "MessageSchedulingState",
    "MessageSchedulingStateSendAtDate",
    "MessageSchedulingStateSendWhenOnline",
    "MessageSendOptions",
    "MessageSender",
    "MessageSenderChat",
    "MessageSenderUser",
    "MessageSenders",
    "MessageSendingState",
    "MessageSendingStateFailed",
    "MessageSendingStatePending",
    "MessageStatistics",
    "MessageThreadInfo",
    "Messages",
    "Minithumbnail",
    "NetworkStatistics",
    "NetworkStatisticsEntry",
    "NetworkStatisticsEntryCall",
    "NetworkStatisticsEntryFile",
    "NetworkType",
    "NetworkTypeMobile",
    "NetworkTypeMobileRoaming",
    "NetworkTypeNone",
    "NetworkTypeOther",
    "NetworkTypeWiFi",
    "Notification",
    "NotificationGroup",
    "NotificationGroupType",
    "NotificationGroupTypeCalls",
    "NotificationGroupTypeMentions",
    "NotificationGroupTypeMessages",
    "NotificationGroupTypeSecretChat",
    "NotificationSettingsScope",
    "NotificationSettingsScopeChannelChats",
    "NotificationSettingsScopeGroupChats",
    "NotificationSettingsScopePrivateChats",
    "NotificationType",
    "NotificationTypeNewCall",
    "NotificationTypeNewMessage",
    "NotificationTypeNewPushMessage",
    "NotificationTypeNewSecretChat",
    "Ok",
    "OptionValue",
    "OptionValueBoolean",
    "OptionValueEmpty",
    "OptionValueInteger",
    "OptionValueString",
    "OrderInfo",
    "PageBlock",
    "PageBlockAnchor",
    "PageBlockAnimation",
    "PageBlockAudio",
    "PageBlockAuthorDate",
    "PageBlockBlockQuote",
    "PageBlockChatLink",
    "PageBlockCollage",
    "PageBlockCover",
    "PageBlockDetails",
    "PageBlockDivider",
    "PageBlockEmbedded",
    "PageBlockEmbeddedPost",
    "PageBlockFooter",
    "PageBlockHeader",
    "PageBlockKicker",
    "PageBlockList",
    "PageBlockMap",
    "PageBlockParagraph",
    "PageBlockPhoto",
    "PageBlockPreformatted",
    "PageBlockPullQuote",
    "PageBlockRelatedArticles",
    "PageBlockSlideshow",
    "PageBlockSubheader",
    "PageBlockSubtitle",
    "PageBlockTable",
    "PageBlockTitle",
    "PageBlockVideo",
    "PageBlockVoiceNote",
    "PageBlockListItem",
    "PageBlockCaption",
    "PageBlockHorizontalAlignment",
    "PageBlockHorizontalAlignmentCenter",
    "PageBlockHorizontalAlignmentLeft",
    "PageBlockHorizontalAlignmentRight",
    "PageBlockRelatedArticle",
    "PageBlockTableCell",
    "PageBlockVerticalAlignment",
    "PageBlockVerticalAlignmentBottom",
    "PageBlockVerticalAlignmentMiddle",
    "PageBlockVerticalAlignmentTop",
    "PassportAuthorizationForm",
    "PassportElement",
    "PassportElementAddress",
    "PassportElementBankStatement",
    "PassportElementDriverLicense",
    "PassportElementEmailAddress",
    "PassportElementIdentityCard",
    "PassportElementInternalPassport",
    "PassportElementPassport",
    "PassportElementPassportRegistration",
    "PassportElementPersonalDetails",
    "PassportElementPhoneNumber",
    "PassportElementRentalAgreement",
    "PassportElementTemporaryRegistration",
    "PassportElementUtilityBill",
    "PassportElementError",
    "PassportElementErrorSource",
    "PassportElementErrorSourceDataField",
    "PassportElementErrorSourceFile",
    "PassportElementErrorSourceFiles",
    "PassportElementErrorSourceFrontSide",
    "PassportElementErrorSourceReverseSide",
    "PassportElementErrorSourceSelfie",
    "PassportElementErrorSourceTranslationFile",
    "PassportElementErrorSourceTranslationFiles",
    "PassportElementErrorSourceUnspecified",
    "PassportElementType",
    "PassportElementTypeAddress",
    "PassportElementTypeBankStatement",
    "PassportElementTypeDriverLicense",
    "PassportElementTypeEmailAddress",
    "PassportElementTypeIdentityCard",
    "PassportElementTypeInternalPassport",
    "PassportElementTypePassport",
    "PassportElementTypePassportRegistration",
    "PassportElementTypePersonalDetails",
    "PassportElementTypePhoneNumber",
    "PassportElementTypeRentalAgreement",
    "PassportElementTypeTemporaryRegistration",
    "PassportElementTypeUtilityBill",
    "PassportElements",
    "PassportElementsWithErrors",
    "PassportRequiredElement",
    "PassportSuitableElement",
    "PasswordState",
    "PaymentForm",
    "PaymentFormTheme",
    "PaymentReceipt",
    "PaymentResult",
    "PaymentsProviderStripe",
    "PersonalDetails",
    "PersonalDocument",
    "PhoneNumberAuthenticationSettings",
    "PhoneNumberInfo",
    "Photo",
    "PhotoSize",
    "Point",
    "Poll",
    "PollOption",
    "PollType",
    "PollTypeQuiz",
    "PollTypeRegular",
    "ProfilePhoto",
    "Proxies",
    "Proxy",
    "ProxyType",
    "ProxyTypeHttp",
    "ProxyTypeMtproto",
    "ProxyTypeSocks5",
    "PublicChatType",
    "PublicChatTypeHasUsername",
    "PublicChatTypeIsLocationBased",
    "PushMessageContent",
    "PushMessageContentAnimation",
    "PushMessageContentAudio",
    "PushMessageContentBasicGroupChatCreate",
    "PushMessageContentChatAddMembers",
    "PushMessageContentChatChangePhoto",
    "PushMessageContentChatChangeTitle",
    "PushMessageContentChatDeleteMember",
    "PushMessageContentChatJoinByLink",
    "PushMessageContentContact",
    "PushMessageContentContactRegistered",
    "PushMessageContentDocument",
    "PushMessageContentGame",
    "PushMessageContentGameScore",
    "PushMessageContentHidden",
    "PushMessageContentInvoice",
    "PushMessageContentLocation",
    "PushMessageContentMediaAlbum",
    "PushMessageContentMessageForwards",
    "PushMessageContentPhoto",
    "PushMessageContentPoll",
    "PushMessageContentScreenshotTaken",
    "PushMessageContentSticker",
    "PushMessageContentText",
    "PushMessageContentVideo",
    "PushMessageContentVideoNote",
    "PushMessageContentVoiceNote",
    "PushReceiverId",
    "RecommendedChatFilter",
    "RecommendedChatFilters",
    "RecoveryEmailAddress",
    "RemoteFile",
    "ReplyMarkup",
    "ReplyMarkupForceReply",
    "ReplyMarkupInlineKeyboard",
    "ReplyMarkupRemoveKeyboard",
    "ReplyMarkupShowKeyboard",
    "ResetPasswordResult",
    "ResetPasswordResultDeclined",
    "ResetPasswordResultOk",
    "ResetPasswordResultPending",
    "RichText",
    "RichTextAnchor",
    "RichTextAnchorLink",
    "RichTextBold",
    "RichTextEmailAddress",
    "RichTextFixed",
    "RichTextIcon",
    "RichTextItalic",
    "RichTextMarked",
    "RichTextPhoneNumber",
    "RichTextPlain",
    "RichTextReference",
    "RichTextStrikethrough",
    "RichTextSubscript",
    "RichTextSuperscript",
    "RichTextUnderline",
    "RichTextUrl",
    "RichTexts",
    "SavedCredentials",
    "ScopeNotificationSettings",
    "SearchMessagesFilter",
    "SearchMessagesFilterAnimation",
    "SearchMessagesFilterAudio",
    "SearchMessagesFilterCall",
    "SearchMessagesFilterChatPhoto",
    "SearchMessagesFilterDocument",
    "SearchMessagesFilterEmpty",
    "SearchMessagesFilterFailedToSend",
    "SearchMessagesFilterMention",
    "SearchMessagesFilterMissedCall",
    "SearchMessagesFilterPhoto",
    "SearchMessagesFilterPhotoAndVideo",
    "SearchMessagesFilterPinned",
    "SearchMessagesFilterUnreadMention",
    "SearchMessagesFilterUrl",
    "SearchMessagesFilterVideo",
    "SearchMessagesFilterVideoNote",
    "SearchMessagesFilterVoiceAndVideoNote",
    "SearchMessagesFilterVoiceNote",
    "Seconds",
    "SecretChat",
    "SecretChatState",
    "SecretChatStateClosed",
    "SecretChatStatePending",
    "SecretChatStateReady",
    "Session",
    "Sessions",
    "ShippingOption",
    "StatisticalGraph",
    "StatisticalGraphAsync",
    "StatisticalGraphData",
    "StatisticalGraphError",
    "StatisticalValue",
    "Sticker",
    "StickerSet",
    "StickerSetInfo",
    "StickerSets",
    "Stickers",
    "StorageStatistics",
    "StorageStatisticsByChat",
    "StorageStatisticsByFileType",
    "StorageStatisticsFast",
    "SuggestedAction",
    "SuggestedActionCheckPassword",
    "SuggestedActionCheckPhoneNumber",
    "SuggestedActionConvertToBroadcastGroup",
    "SuggestedActionEnableArchiveAndMuteNewChats",
    "SuggestedActionSeeTicksHint",
    "Supergroup",
    "SupergroupFullInfo",
    "SupergroupMembersFilter",
    "SupergroupMembersFilterAdministrators",
    "SupergroupMembersFilterBanned",
    "SupergroupMembersFilterBots",
    "SupergroupMembersFilterContacts",
    "SupergroupMembersFilterMention",
    "SupergroupMembersFilterRecent",
    "SupergroupMembersFilterRestricted",
    "SupergroupMembersFilterSearch",
    "TMeUrl",
    "TMeUrlType",
    "TMeUrlTypeChatInvite",
    "TMeUrlTypeStickerSet",
    "TMeUrlTypeSupergroup",
    "TMeUrlTypeUser",
    "TMeUrls",
    "TdlibParameters",
    "TemporaryPasswordState",
    "TermsOfService",
    "TestBytes",
    "TestInt",
    "TestString",
    "TestVectorInt",
    "TestVectorIntObject",
    "TestVectorString",
    "TestVectorStringObject",
    "Text",
    "TextEntities",
    "TextEntity",
    "TextEntityType",
    "TextEntityTypeBankCardNumber",
    "TextEntityTypeBold",
    "TextEntityTypeBotCommand",
    "TextEntityTypeCashtag",
    "TextEntityTypeCode",
    "TextEntityTypeEmailAddress",
    "TextEntityTypeHashtag",
    "TextEntityTypeItalic",
    "TextEntityTypeMention",
    "TextEntityTypeMentionName",
    "TextEntityTypePhoneNumber",
    "TextEntityTypePre",
    "TextEntityTypePreCode",
    "TextEntityTypeStrikethrough",
    "TextEntityTypeTextUrl",
    "TextEntityTypeUnderline",
    "TextEntityTypeUrl",
    "TextParseMode",
    "TextParseModeHTML",
    "TextParseModeMarkdown",
    "Thumbnail",
    "ThumbnailFormat",
    "ThumbnailFormatGif",
    "ThumbnailFormatJpeg",
    "ThumbnailFormatMpeg4",
    "ThumbnailFormatPng",
    "ThumbnailFormatTgs",
    "ThumbnailFormatWebp",
    "TopChatCategory",
    "TopChatCategoryBots",
    "TopChatCategoryCalls",
    "TopChatCategoryChannels",
    "TopChatCategoryForwardChats",
    "TopChatCategoryGroups",
    "TopChatCategoryInlineBots",
    "TopChatCategoryUsers",
    "Update",
    "UpdateActiveNotifications",
    "UpdateAnimationSearchParameters",
    "UpdateAuthorizationState",
    "UpdateBasicGroup",
    "UpdateBasicGroupFullInfo",
    "UpdateCall",
    "UpdateChatActionBar",
    "UpdateChatDefaultDisableNotification",
    "UpdateChatDraftMessage",
    "UpdateChatFilters",
    "UpdateChatHasScheduledMessages",
    "UpdateChatIsBlocked",
    "UpdateChatIsMarkedAsUnread",
    "UpdateChatLastMessage",
    "UpdateChatMember",
    "UpdateChatMessageTtlSetting",
    "UpdateChatNotificationSettings",
    "UpdateChatOnlineMemberCount",
    "UpdateChatPermissions",
    "UpdateChatPhoto",
    "UpdateChatPosition",
    "UpdateChatReadInbox",
    "UpdateChatReadOutbox",
    "UpdateChatReplyMarkup",
    "UpdateChatTitle",
    "UpdateChatUnreadMentionCount",
    "UpdateChatVoiceChat",
    "UpdateConnectionState",
    "UpdateDeleteMessages",
    "UpdateDiceEmojis",
    "UpdateFavoriteStickers",
    "UpdateFile",
    "UpdateFileGenerationStart",
    "UpdateFileGenerationStop",
    "UpdateGroupCall",
    "UpdateGroupCallParticipant",
    "UpdateHavePendingNotifications",
    "UpdateInstalledStickerSets",
    "UpdateLanguagePackStrings",
    "UpdateMessageContent",
    "UpdateMessageContentOpened",
    "UpdateMessageEdited",
    "UpdateMessageInteractionInfo",
    "UpdateMessageIsPinned",
    "UpdateMessageLiveLocationViewed",
    "UpdateMessageMentionRead",
    "UpdateMessageSendAcknowledged",
    "UpdateMessageSendFailed",
    "UpdateMessageSendSucceeded",
    "UpdateNewCallSignalingData",
    "UpdateNewCallbackQuery",
    "UpdateNewChat",
    "UpdateNewChosenInlineResult",
    "UpdateNewCustomEvent",
    "UpdateNewCustomQuery",
    "UpdateNewInlineCallbackQuery",
    "UpdateNewInlineQuery",
    "UpdateNewMessage",
    "UpdateNewPreCheckoutQuery",
    "UpdateNewShippingQuery",
    "UpdateNotification",
    "UpdateNotificationGroup",
    "UpdateOption",
    "UpdatePoll",
    "UpdatePollAnswer",
    "UpdateRecentStickers",
    "UpdateSavedAnimations",
    "UpdateScopeNotificationSettings",
    "UpdateSecretChat",
    "UpdateSelectedBackground",
    "UpdateServiceNotification",
    "UpdateStickerSet",
    "UpdateSuggestedActions",
    "UpdateSupergroup",
    "UpdateSupergroupFullInfo",
    "UpdateTermsOfService",
    "UpdateTrendingStickerSets",
    "UpdateUnreadChatCount",
    "UpdateUnreadMessageCount",
    "UpdateUser",
    "UpdateUserChatAction",
    "UpdateUserFullInfo",
    "UpdateUserPrivacySettingRules",
    "UpdateUserStatus",
    "UpdateUsersNearby",
    "Updates",
    "User",
    "UserFullInfo",
    "UserPrivacySetting",
    "UserPrivacySettingAllowCalls",
    "UserPrivacySettingAllowChatInvites",
    "UserPrivacySettingAllowFindingByPhoneNumber",
    "UserPrivacySettingAllowPeerToPeerCalls",
    "UserPrivacySettingShowLinkInForwardedMessages",
    "UserPrivacySettingShowPhoneNumber",
    "UserPrivacySettingShowProfilePhoto",
    "UserPrivacySettingShowStatus",
    "UserPrivacySettingRule",
    "UserPrivacySettingRuleAllowAll",
    "UserPrivacySettingRuleAllowChatMembers",
    "UserPrivacySettingRuleAllowContacts",
    "UserPrivacySettingRuleAllowUsers",
    "UserPrivacySettingRuleRestrictAll",
    "UserPrivacySettingRuleRestrictChatMembers",
    "UserPrivacySettingRuleRestrictContacts",
    "UserPrivacySettingRuleRestrictUsers",
    "UserPrivacySettingRules",
    "UserStatus",
    "UserStatusEmpty",
    "UserStatusLastMonth",
    "UserStatusLastWeek",
    "UserStatusOffline",
    "UserStatusOnline",
    "UserStatusRecently",
    "UserType",
    "UserTypeBot",
    "UserTypeDeleted",
    "UserTypeRegular",
    "UserTypeUnknown",
    "Users",
    "ValidatedOrderInfo",
    "VectorPathCommand",
    "VectorPathCommandCubicBezierCurve",
    "VectorPathCommandLine",
    "Venue",
    "Video",
    "VideoNote",
    "VoiceChat",
    "VoiceNote",
    "WebPage",
    "WebPageInstantView",
]
