# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #

from .accept_call import AcceptCall
from .accept_terms_of_service import AcceptTermsOfService
from .add_chat_member import AddChatMember
from .add_chat_members import AddChatMembers
from .add_chat_to_list import AddChatToList
from .add_contact import AddContact
from .add_custom_server_language_pack import AddCustomServerLanguagePack
from .add_favorite_sticker import AddFavoriteSticker
from .add_local_message import AddLocalMessage
from .add_log_message import AddLogMessage
from .add_network_statistics import AddNetworkStatistics
from .add_proxy import AddProxy
from .add_recent_sticker import AddRecentSticker
from .add_recently_found_chat import AddRecentlyFoundChat
from .add_saved_animation import AddSavedAnimation
from .add_sticker_to_set import AddStickerToSet
from .answer_callback_query import AnswerCallbackQuery
from .answer_custom_query import AnswerCustomQuery
from .answer_inline_query import AnswerInlineQuery
from .answer_pre_checkout_query import AnswerPreCheckoutQuery
from .answer_shipping_query import AnswerShippingQuery
from .ban_chat_member import BanChatMember
from .block_message_sender_from_replies import BlockMessageSenderFromReplies
from .can_transfer_ownership import CanTransferOwnership
from .cancel_download_file import CancelDownloadFile
from .cancel_password_reset import CancelPasswordReset
from .cancel_upload_file import CancelUploadFile
from .change_imported_contacts import ChangeImportedContacts
from .change_phone_number import ChangePhoneNumber
from .change_sticker_set import ChangeStickerSet
from .check_authentication_bot_token import CheckAuthenticationBotToken
from .check_authentication_code import CheckAuthenticationCode
from .check_authentication_password import CheckAuthenticationPassword
from .check_authentication_password_recovery_code import CheckAuthenticationPasswordRecoveryCode
from .check_change_phone_number_code import CheckChangePhoneNumberCode
from .check_chat_invite_link import CheckChatInviteLink
from .check_chat_username import CheckChatUsername
from .check_created_public_chats_limit import CheckCreatedPublicChatsLimit
from .check_database_encryption_key import CheckDatabaseEncryptionKey
from .check_email_address_verification_code import CheckEmailAddressVerificationCode
from .check_password_recovery_code import CheckPasswordRecoveryCode
from .check_phone_number_confirmation_code import CheckPhoneNumberConfirmationCode
from .check_phone_number_verification_code import CheckPhoneNumberVerificationCode
from .check_recovery_email_address_code import CheckRecoveryEmailAddressCode
from .check_sticker_set_name import CheckStickerSetName
from .clean_file_name import CleanFileName
from .clear_all_draft_messages import ClearAllDraftMessages
from .clear_imported_contacts import ClearImportedContacts
from .clear_recent_stickers import ClearRecentStickers
from .clear_recently_found_chats import ClearRecentlyFoundChats
from .close import Close
from .close_chat import CloseChat
from .close_secret_chat import CloseSecretChat
from .confirm_qr_code_authentication import ConfirmQrCodeAuthentication
from .create_basic_group_chat import CreateBasicGroupChat
from .create_call import CreateCall
from .create_chat_filter import CreateChatFilter
from .create_chat_invite_link import CreateChatInviteLink
from .create_new_basic_group_chat import CreateNewBasicGroupChat
from .create_new_secret_chat import CreateNewSecretChat
from .create_new_sticker_set import CreateNewStickerSet
from .create_new_supergroup_chat import CreateNewSupergroupChat
from .create_private_chat import CreatePrivateChat
from .create_secret_chat import CreateSecretChat
from .create_supergroup_chat import CreateSupergroupChat
from .create_temporary_password import CreateTemporaryPassword
from .create_voice_chat import CreateVoiceChat
from .delete_account import DeleteAccount
from .delete_all_call_messages import DeleteAllCallMessages
from .delete_all_revoked_chat_invite_links import DeleteAllRevokedChatInviteLinks
from .delete_chat import DeleteChat
from .delete_chat_filter import DeleteChatFilter
from .delete_chat_history import DeleteChatHistory
from .delete_chat_messages_from_user import DeleteChatMessagesFromUser
from .delete_chat_reply_markup import DeleteChatReplyMarkup
from .delete_commands import DeleteCommands
from .delete_file import DeleteFile
from .delete_language_pack import DeleteLanguagePack
from .delete_messages import DeleteMessages
from .delete_passport_element import DeletePassportElement
from .delete_profile_photo import DeleteProfilePhoto
from .delete_revoked_chat_invite_link import DeleteRevokedChatInviteLink
from .delete_saved_credentials import DeleteSavedCredentials
from .delete_saved_order_info import DeleteSavedOrderInfo
from .destroy import Destroy
from .disable_proxy import DisableProxy
from .discard_call import DiscardCall
from .discard_group_call import DiscardGroupCall
from .disconnect_all_websites import DisconnectAllWebsites
from .disconnect_website import DisconnectWebsite
from .download_file import DownloadFile
from .edit_chat_filter import EditChatFilter
from .edit_chat_invite_link import EditChatInviteLink
from .edit_custom_language_pack_info import EditCustomLanguagePackInfo
from .edit_inline_message_caption import EditInlineMessageCaption
from .edit_inline_message_live_location import EditInlineMessageLiveLocation
from .edit_inline_message_media import EditInlineMessageMedia
from .edit_inline_message_reply_markup import EditInlineMessageReplyMarkup
from .edit_inline_message_text import EditInlineMessageText
from .edit_message_caption import EditMessageCaption
from .edit_message_live_location import EditMessageLiveLocation
from .edit_message_media import EditMessageMedia
from .edit_message_reply_markup import EditMessageReplyMarkup
from .edit_message_scheduling_state import EditMessageSchedulingState
from .edit_message_text import EditMessageText
from .edit_proxy import EditProxy
from .enable_proxy import EnableProxy
from .end_group_call_recording import EndGroupCallRecording
from .end_group_call_screen_sharing import EndGroupCallScreenSharing
from .finish_file_generation import FinishFileGeneration
from .forward_messages import ForwardMessages
from .get_account_ttl import GetAccountTtl
from .get_active_live_location_messages import GetActiveLiveLocationMessages
from .get_active_sessions import GetActiveSessions
from .get_all_passport_elements import GetAllPassportElements
from .get_application_config import GetApplicationConfig
from .get_application_download_link import GetApplicationDownloadLink
from .get_archived_sticker_sets import GetArchivedStickerSets
from .get_attached_sticker_sets import GetAttachedStickerSets
from .get_authorization_state import GetAuthorizationState
from .get_auto_download_settings_presets import GetAutoDownloadSettingsPresets
from .get_background_url import GetBackgroundUrl
from .get_backgrounds import GetBackgrounds
from .get_bank_card_info import GetBankCardInfo
from .get_basic_group import GetBasicGroup
from .get_basic_group_full_info import GetBasicGroupFullInfo
from .get_blocked_message_senders import GetBlockedMessageSenders
from .get_callback_query_answer import GetCallbackQueryAnswer
from .get_callback_query_message import GetCallbackQueryMessage
from .get_chat import GetChat
from .get_chat_administrators import GetChatAdministrators
from .get_chat_event_log import GetChatEventLog
from .get_chat_filter import GetChatFilter
from .get_chat_filter_default_icon_name import GetChatFilterDefaultIconName
from .get_chat_history import GetChatHistory
from .get_chat_invite_link import GetChatInviteLink
from .get_chat_invite_link_counts import GetChatInviteLinkCounts
from .get_chat_invite_link_members import GetChatInviteLinkMembers
from .get_chat_invite_links import GetChatInviteLinks
from .get_chat_lists_to_add_chat import GetChatListsToAddChat
from .get_chat_member import GetChatMember
from .get_chat_message_by_date import GetChatMessageByDate
from .get_chat_message_count import GetChatMessageCount
from .get_chat_notification_settings_exceptions import GetChatNotificationSettingsExceptions
from .get_chat_pinned_message import GetChatPinnedMessage
from .get_chat_scheduled_messages import GetChatScheduledMessages
from .get_chat_statistics import GetChatStatistics
from .get_chat_statistics_url import GetChatStatisticsUrl
from .get_chats import GetChats
from .get_commands import GetCommands
from .get_connected_websites import GetConnectedWebsites
from .get_contacts import GetContacts
from .get_countries import GetCountries
from .get_country_code import GetCountryCode
from .get_created_public_chats import GetCreatedPublicChats
from .get_current_state import GetCurrentState
from .get_database_statistics import GetDatabaseStatistics
from .get_deep_link_info import GetDeepLinkInfo
from .get_emoji_suggestions_url import GetEmojiSuggestionsUrl
from .get_external_link import GetExternalLink
from .get_external_link_info import GetExternalLinkInfo
from .get_favorite_stickers import GetFavoriteStickers
from .get_file import GetFile
from .get_file_downloaded_prefix_size import GetFileDownloadedPrefixSize
from .get_file_extension import GetFileExtension
from .get_file_mime_type import GetFileMimeType
from .get_game_high_scores import GetGameHighScores
from .get_group_call import GetGroupCall
from .get_group_call_invite_link import GetGroupCallInviteLink
from .get_group_call_stream_segment import GetGroupCallStreamSegment
from .get_groups_in_common import GetGroupsInCommon
from .get_imported_contact_count import GetImportedContactCount
from .get_inactive_supergroup_chats import GetInactiveSupergroupChats
from .get_inline_game_high_scores import GetInlineGameHighScores
from .get_inline_query_results import GetInlineQueryResults
from .get_installed_sticker_sets import GetInstalledStickerSets
from .get_internal_link_type import GetInternalLinkType
from .get_json_string import GetJsonString
from .get_json_value import GetJsonValue
from .get_language_pack_info import GetLanguagePackInfo
from .get_language_pack_string import GetLanguagePackString
from .get_language_pack_strings import GetLanguagePackStrings
from .get_localization_target_info import GetLocalizationTargetInfo
from .get_log_stream import GetLogStream
from .get_log_tag_verbosity_level import GetLogTagVerbosityLevel
from .get_log_tags import GetLogTags
from .get_log_verbosity_level import GetLogVerbosityLevel
from .get_login_url import GetLoginUrl
from .get_login_url_info import GetLoginUrlInfo
from .get_map_thumbnail_file import GetMapThumbnailFile
from .get_markdown_text import GetMarkdownText
from .get_me import GetMe
from .get_message import GetMessage
from .get_message_embedding_code import GetMessageEmbeddingCode
from .get_message_file_type import GetMessageFileType
from .get_message_import_confirmation_text import GetMessageImportConfirmationText
from .get_message_link import GetMessageLink
from .get_message_link_info import GetMessageLinkInfo
from .get_message_locally import GetMessageLocally
from .get_message_public_forwards import GetMessagePublicForwards
from .get_message_statistics import GetMessageStatistics
from .get_message_thread import GetMessageThread
from .get_message_thread_history import GetMessageThreadHistory
from .get_messages import GetMessages
from .get_network_statistics import GetNetworkStatistics
from .get_option import GetOption
from .get_passport_authorization_form import GetPassportAuthorizationForm
from .get_passport_authorization_form_available_elements import GetPassportAuthorizationFormAvailableElements
from .get_passport_element import GetPassportElement
from .get_password_state import GetPasswordState
from .get_payment_form import GetPaymentForm
from .get_payment_receipt import GetPaymentReceipt
from .get_phone_number_info import GetPhoneNumberInfo
from .get_poll_voters import GetPollVoters
from .get_preferred_country_language import GetPreferredCountryLanguage
from .get_proxies import GetProxies
from .get_proxy_link import GetProxyLink
from .get_push_receiver_id import GetPushReceiverId
from .get_recent_inline_bots import GetRecentInlineBots
from .get_recent_stickers import GetRecentStickers
from .get_recently_visited_t_me_urls import GetRecentlyVisitedTMeUrls
from .get_recommended_chat_filters import GetRecommendedChatFilters
from .get_recovery_email_address import GetRecoveryEmailAddress
from .get_remote_file import GetRemoteFile
from .get_replied_message import GetRepliedMessage
from .get_saved_animations import GetSavedAnimations
from .get_saved_order_info import GetSavedOrderInfo
from .get_scope_notification_settings import GetScopeNotificationSettings
from .get_secret_chat import GetSecretChat
from .get_statistical_graph import GetStatisticalGraph
from .get_sticker_emojis import GetStickerEmojis
from .get_sticker_set import GetStickerSet
from .get_stickers import GetStickers
from .get_storage_statistics import GetStorageStatistics
from .get_storage_statistics_fast import GetStorageStatisticsFast
from .get_suggested_file_name import GetSuggestedFileName
from .get_suggested_sticker_set_name import GetSuggestedStickerSetName
from .get_suitable_discussion_chats import GetSuitableDiscussionChats
from .get_supergroup import GetSupergroup
from .get_supergroup_full_info import GetSupergroupFullInfo
from .get_supergroup_members import GetSupergroupMembers
from .get_support_user import GetSupportUser
from .get_temporary_password_state import GetTemporaryPasswordState
from .get_text_entities import GetTextEntities
from .get_top_chats import GetTopChats
from .get_trending_sticker_sets import GetTrendingStickerSets
from .get_user import GetUser
from .get_user_full_info import GetUserFullInfo
from .get_user_privacy_setting_rules import GetUserPrivacySettingRules
from .get_user_profile_photos import GetUserProfilePhotos
from .get_voice_chat_available_participants import GetVoiceChatAvailableParticipants
from .get_web_page_instant_view import GetWebPageInstantView
from .get_web_page_preview import GetWebPagePreview
from .hide_suggested_action import HideSuggestedAction
from .import_contacts import ImportContacts
from .import_messages import ImportMessages
from .invite_group_call_participants import InviteGroupCallParticipants
from .join_chat import JoinChat
from .join_chat_by_invite_link import JoinChatByInviteLink
from .join_group_call import JoinGroupCall
from .leave_chat import LeaveChat
from .leave_group_call import LeaveGroupCall
from .load_group_call_participants import LoadGroupCallParticipants
from .log_out import LogOut
from .open_chat import OpenChat
from .open_message_content import OpenMessageContent
from .optimize_storage import OptimizeStorage
from .parse_markdown import ParseMarkdown
from .parse_text_entities import ParseTextEntities
from .pin_chat_message import PinChatMessage
from .ping_proxy import PingProxy
from .process_push_notification import ProcessPushNotification
from .read_all_chat_mentions import ReadAllChatMentions
from .read_file_part import ReadFilePart
from .recover_authentication_password import RecoverAuthenticationPassword
from .recover_password import RecoverPassword
from .register_device import RegisterDevice
from .register_user import RegisterUser
from .remove_background import RemoveBackground
from .remove_chat_action_bar import RemoveChatActionBar
from .remove_contacts import RemoveContacts
from .remove_favorite_sticker import RemoveFavoriteSticker
from .remove_notification import RemoveNotification
from .remove_notification_group import RemoveNotificationGroup
from .remove_proxy import RemoveProxy
from .remove_recent_hashtag import RemoveRecentHashtag
from .remove_recent_sticker import RemoveRecentSticker
from .remove_recently_found_chat import RemoveRecentlyFoundChat
from .remove_saved_animation import RemoveSavedAnimation
from .remove_sticker_from_set import RemoveStickerFromSet
from .remove_top_chat import RemoveTopChat
from .reorder_chat_filters import ReorderChatFilters
from .reorder_installed_sticker_sets import ReorderInstalledStickerSets
from .replace_primary_chat_invite_link import ReplacePrimaryChatInviteLink
from .report_chat import ReportChat
from .report_chat_photo import ReportChatPhoto
from .report_supergroup_spam import ReportSupergroupSpam
from .request_authentication_password_recovery import RequestAuthenticationPasswordRecovery
from .request_password_recovery import RequestPasswordRecovery
from .request_qr_code_authentication import RequestQrCodeAuthentication
from .resend_authentication_code import ResendAuthenticationCode
from .resend_change_phone_number_code import ResendChangePhoneNumberCode
from .resend_email_address_verification_code import ResendEmailAddressVerificationCode
from .resend_messages import ResendMessages
from .resend_phone_number_confirmation_code import ResendPhoneNumberConfirmationCode
from .resend_phone_number_verification_code import ResendPhoneNumberVerificationCode
from .resend_recovery_email_address_code import ResendRecoveryEmailAddressCode
from .reset_all_notification_settings import ResetAllNotificationSettings
from .reset_backgrounds import ResetBackgrounds
from .reset_network_statistics import ResetNetworkStatistics
from .reset_password import ResetPassword
from .revoke_chat_invite_link import RevokeChatInviteLink
from .revoke_group_call_invite_link import RevokeGroupCallInviteLink
from .save_application_log_event import SaveApplicationLogEvent
from .search_background import SearchBackground
from .search_call_messages import SearchCallMessages
from .search_chat_members import SearchChatMembers
from .search_chat_messages import SearchChatMessages
from .search_chat_recent_location_messages import SearchChatRecentLocationMessages
from .search_chats import SearchChats
from .search_chats_nearby import SearchChatsNearby
from .search_chats_on_server import SearchChatsOnServer
from .search_contacts import SearchContacts
from .search_emojis import SearchEmojis
from .search_hashtags import SearchHashtags
from .search_installed_sticker_sets import SearchInstalledStickerSets
from .search_messages import SearchMessages
from .search_public_chat import SearchPublicChat
from .search_public_chats import SearchPublicChats
from .search_secret_messages import SearchSecretMessages
from .search_sticker_set import SearchStickerSet
from .search_sticker_sets import SearchStickerSets
from .search_stickers import SearchStickers
from .send_bot_start_message import SendBotStartMessage
from .send_call_debug_information import SendCallDebugInformation
from .send_call_rating import SendCallRating
from .send_call_signaling_data import SendCallSignalingData
from .send_chat_action import SendChatAction
from .send_chat_screenshot_taken_notification import SendChatScreenshotTakenNotification
from .send_custom_request import SendCustomRequest
from .send_email_address_verification_code import SendEmailAddressVerificationCode
from .send_inline_query_result_message import SendInlineQueryResultMessage
from .send_message import SendMessage
from .send_message_album import SendMessageAlbum
from .send_passport_authorization_form import SendPassportAuthorizationForm
from .send_payment_form import SendPaymentForm
from .send_phone_number_confirmation_code import SendPhoneNumberConfirmationCode
from .send_phone_number_verification_code import SendPhoneNumberVerificationCode
from .set_account_ttl import SetAccountTtl
from .set_alarm import SetAlarm
from .set_authentication_phone_number import SetAuthenticationPhoneNumber
from .set_auto_download_settings import SetAutoDownloadSettings
from .set_background import SetBackground
from .set_bio import SetBio
from .set_bot_updates_status import SetBotUpdatesStatus
from .set_chat_client_data import SetChatClientData
from .set_chat_description import SetChatDescription
from .set_chat_discussion_group import SetChatDiscussionGroup
from .set_chat_draft_message import SetChatDraftMessage
from .set_chat_location import SetChatLocation
from .set_chat_member_status import SetChatMemberStatus
from .set_chat_message_ttl_setting import SetChatMessageTtlSetting
from .set_chat_notification_settings import SetChatNotificationSettings
from .set_chat_permissions import SetChatPermissions
from .set_chat_photo import SetChatPhoto
from .set_chat_slow_mode_delay import SetChatSlowModeDelay
from .set_chat_title import SetChatTitle
from .set_commands import SetCommands
from .set_custom_language_pack import SetCustomLanguagePack
from .set_custom_language_pack_string import SetCustomLanguagePackString
from .set_database_encryption_key import SetDatabaseEncryptionKey
from .set_file_generation_progress import SetFileGenerationProgress
from .set_game_score import SetGameScore
from .set_group_call_participant_is_speaking import SetGroupCallParticipantIsSpeaking
from .set_group_call_participant_volume_level import SetGroupCallParticipantVolumeLevel
from .set_group_call_title import SetGroupCallTitle
from .set_inline_game_score import SetInlineGameScore
from .set_location import SetLocation
from .set_log_stream import SetLogStream
from .set_log_tag_verbosity_level import SetLogTagVerbosityLevel
from .set_log_verbosity_level import SetLogVerbosityLevel
from .set_name import SetName
from .set_network_type import SetNetworkType
from .set_option import SetOption
from .set_passport_element import SetPassportElement
from .set_passport_element_errors import SetPassportElementErrors
from .set_password import SetPassword
from .set_pinned_chats import SetPinnedChats
from .set_poll_answer import SetPollAnswer
from .set_profile_photo import SetProfilePhoto
from .set_recovery_email_address import SetRecoveryEmailAddress
from .set_scope_notification_settings import SetScopeNotificationSettings
from .set_sticker_position_in_set import SetStickerPositionInSet
from .set_sticker_set_thumbnail import SetStickerSetThumbnail
from .set_supergroup_sticker_set import SetSupergroupStickerSet
from .set_supergroup_username import SetSupergroupUsername
from .set_tdlib_parameters import SetTdlibParameters
from .set_user_privacy_setting_rules import SetUserPrivacySettingRules
from .set_username import SetUsername
from .set_voice_chat_default_participant import SetVoiceChatDefaultParticipant
from .share_phone_number import SharePhoneNumber
from .start_group_call_recording import StartGroupCallRecording
from .start_group_call_screen_sharing import StartGroupCallScreenSharing
from .start_scheduled_group_call import StartScheduledGroupCall
from .stop_poll import StopPoll
from .synchronize_language_pack import SynchronizeLanguagePack
from .terminate_all_other_sessions import TerminateAllOtherSessions
from .terminate_session import TerminateSession
from .test_call_bytes import TestCallBytes
from .test_call_empty import TestCallEmpty
from .test_call_string import TestCallString
from .test_call_vector_int import TestCallVectorInt
from .test_call_vector_int_object import TestCallVectorIntObject
from .test_call_vector_string import TestCallVectorString
from .test_call_vector_string_object import TestCallVectorStringObject
from .test_get_difference import TestGetDifference
from .test_network import TestNetwork
from .test_proxy import TestProxy
from .test_return_error import TestReturnError
from .test_square_int import TestSquareInt
from .test_use_update import TestUseUpdate
from .toggle_chat_default_disable_notification import ToggleChatDefaultDisableNotification
from .toggle_chat_is_marked_as_unread import ToggleChatIsMarkedAsUnread
from .toggle_chat_is_pinned import ToggleChatIsPinned
from .toggle_group_call_enabled_start_notification import ToggleGroupCallEnabledStartNotification
from .toggle_group_call_is_my_video_enabled import ToggleGroupCallIsMyVideoEnabled
from .toggle_group_call_is_my_video_paused import ToggleGroupCallIsMyVideoPaused
from .toggle_group_call_mute_new_participants import ToggleGroupCallMuteNewParticipants
from .toggle_group_call_participant_is_hand_raised import ToggleGroupCallParticipantIsHandRaised
from .toggle_group_call_participant_is_muted import ToggleGroupCallParticipantIsMuted
from .toggle_group_call_screen_sharing_is_paused import ToggleGroupCallScreenSharingIsPaused
from .toggle_message_sender_is_blocked import ToggleMessageSenderIsBlocked
from .toggle_supergroup_is_all_history_available import ToggleSupergroupIsAllHistoryAvailable
from .toggle_supergroup_is_broadcast_group import ToggleSupergroupIsBroadcastGroup
from .toggle_supergroup_sign_messages import ToggleSupergroupSignMessages
from .transfer_chat_ownership import TransferChatOwnership
from .unpin_all_chat_messages import UnpinAllChatMessages
from .unpin_chat_message import UnpinChatMessage
from .upgrade_basic_group_chat_to_supergroup_chat import UpgradeBasicGroupChatToSupergroupChat
from .upload_file import UploadFile
from .upload_sticker_file import UploadStickerFile
from .validate_order_info import ValidateOrderInfo
from .view_messages import ViewMessages
from .view_trending_sticker_sets import ViewTrendingStickerSets
from .write_generated_file_part import WriteGeneratedFilePart

__all__ = [
    "AcceptCall",
    "AcceptTermsOfService",
    "AddChatMember",
    "AddChatMembers",
    "AddChatToList",
    "AddContact",
    "AddCustomServerLanguagePack",
    "AddFavoriteSticker",
    "AddLocalMessage",
    "AddLogMessage",
    "AddNetworkStatistics",
    "AddProxy",
    "AddRecentSticker",
    "AddRecentlyFoundChat",
    "AddSavedAnimation",
    "AddStickerToSet",
    "AnswerCallbackQuery",
    "AnswerCustomQuery",
    "AnswerInlineQuery",
    "AnswerPreCheckoutQuery",
    "AnswerShippingQuery",
    "BanChatMember",
    "BlockMessageSenderFromReplies",
    "CanTransferOwnership",
    "CancelDownloadFile",
    "CancelPasswordReset",
    "CancelUploadFile",
    "ChangeImportedContacts",
    "ChangePhoneNumber",
    "ChangeStickerSet",
    "CheckAuthenticationBotToken",
    "CheckAuthenticationCode",
    "CheckAuthenticationPassword",
    "CheckAuthenticationPasswordRecoveryCode",
    "CheckChangePhoneNumberCode",
    "CheckChatInviteLink",
    "CheckChatUsername",
    "CheckCreatedPublicChatsLimit",
    "CheckDatabaseEncryptionKey",
    "CheckEmailAddressVerificationCode",
    "CheckPasswordRecoveryCode",
    "CheckPhoneNumberConfirmationCode",
    "CheckPhoneNumberVerificationCode",
    "CheckRecoveryEmailAddressCode",
    "CheckStickerSetName",
    "CleanFileName",
    "ClearAllDraftMessages",
    "ClearImportedContacts",
    "ClearRecentStickers",
    "ClearRecentlyFoundChats",
    "Close",
    "CloseChat",
    "CloseSecretChat",
    "ConfirmQrCodeAuthentication",
    "CreateBasicGroupChat",
    "CreateCall",
    "CreateChatFilter",
    "CreateChatInviteLink",
    "CreateNewBasicGroupChat",
    "CreateNewSecretChat",
    "CreateNewStickerSet",
    "CreateNewSupergroupChat",
    "CreatePrivateChat",
    "CreateSecretChat",
    "CreateSupergroupChat",
    "CreateTemporaryPassword",
    "CreateVoiceChat",
    "DeleteAccount",
    "DeleteAllCallMessages",
    "DeleteAllRevokedChatInviteLinks",
    "DeleteChat",
    "DeleteChatFilter",
    "DeleteChatHistory",
    "DeleteChatMessagesFromUser",
    "DeleteChatReplyMarkup",
    "DeleteCommands",
    "DeleteFile",
    "DeleteLanguagePack",
    "DeleteMessages",
    "DeletePassportElement",
    "DeleteProfilePhoto",
    "DeleteRevokedChatInviteLink",
    "DeleteSavedCredentials",
    "DeleteSavedOrderInfo",
    "Destroy",
    "DisableProxy",
    "DiscardCall",
    "DiscardGroupCall",
    "DisconnectAllWebsites",
    "DisconnectWebsite",
    "DownloadFile",
    "EditChatFilter",
    "EditChatInviteLink",
    "EditCustomLanguagePackInfo",
    "EditInlineMessageCaption",
    "EditInlineMessageLiveLocation",
    "EditInlineMessageMedia",
    "EditInlineMessageReplyMarkup",
    "EditInlineMessageText",
    "EditMessageCaption",
    "EditMessageLiveLocation",
    "EditMessageMedia",
    "EditMessageReplyMarkup",
    "EditMessageSchedulingState",
    "EditMessageText",
    "EditProxy",
    "EnableProxy",
    "EndGroupCallRecording",
    "EndGroupCallScreenSharing",
    "FinishFileGeneration",
    "ForwardMessages",
    "GetAccountTtl",
    "GetActiveLiveLocationMessages",
    "GetActiveSessions",
    "GetAllPassportElements",
    "GetApplicationConfig",
    "GetApplicationDownloadLink",
    "GetArchivedStickerSets",
    "GetAttachedStickerSets",
    "GetAuthorizationState",
    "GetAutoDownloadSettingsPresets",
    "GetBackgroundUrl",
    "GetBackgrounds",
    "GetBankCardInfo",
    "GetBasicGroup",
    "GetBasicGroupFullInfo",
    "GetBlockedMessageSenders",
    "GetCallbackQueryAnswer",
    "GetCallbackQueryMessage",
    "GetChat",
    "GetChatAdministrators",
    "GetChatEventLog",
    "GetChatFilter",
    "GetChatFilterDefaultIconName",
    "GetChatHistory",
    "GetChatInviteLink",
    "GetChatInviteLinkCounts",
    "GetChatInviteLinkMembers",
    "GetChatInviteLinks",
    "GetChatListsToAddChat",
    "GetChatMember",
    "GetChatMessageByDate",
    "GetChatMessageCount",
    "GetChatNotificationSettingsExceptions",
    "GetChatPinnedMessage",
    "GetChatScheduledMessages",
    "GetChatStatistics",
    "GetChatStatisticsUrl",
    "GetChats",
    "GetCommands",
    "GetConnectedWebsites",
    "GetContacts",
    "GetCountries",
    "GetCountryCode",
    "GetCreatedPublicChats",
    "GetCurrentState",
    "GetDatabaseStatistics",
    "GetDeepLinkInfo",
    "GetEmojiSuggestionsUrl",
    "GetExternalLink",
    "GetExternalLinkInfo",
    "GetFavoriteStickers",
    "GetFile",
    "GetFileDownloadedPrefixSize",
    "GetFileExtension",
    "GetFileMimeType",
    "GetGameHighScores",
    "GetGroupCall",
    "GetGroupCallInviteLink",
    "GetGroupCallStreamSegment",
    "GetGroupsInCommon",
    "GetImportedContactCount",
    "GetInactiveSupergroupChats",
    "GetInlineGameHighScores",
    "GetInlineQueryResults",
    "GetInstalledStickerSets",
    "GetInternalLinkType",
    "GetJsonString",
    "GetJsonValue",
    "GetLanguagePackInfo",
    "GetLanguagePackString",
    "GetLanguagePackStrings",
    "GetLocalizationTargetInfo",
    "GetLogStream",
    "GetLogTagVerbosityLevel",
    "GetLogTags",
    "GetLogVerbosityLevel",
    "GetLoginUrl",
    "GetLoginUrlInfo",
    "GetMapThumbnailFile",
    "GetMarkdownText",
    "GetMe",
    "GetMessage",
    "GetMessageEmbeddingCode",
    "GetMessageFileType",
    "GetMessageImportConfirmationText",
    "GetMessageLink",
    "GetMessageLinkInfo",
    "GetMessageLocally",
    "GetMessagePublicForwards",
    "GetMessageStatistics",
    "GetMessageThread",
    "GetMessageThreadHistory",
    "GetMessages",
    "GetNetworkStatistics",
    "GetOption",
    "GetPassportAuthorizationForm",
    "GetPassportAuthorizationFormAvailableElements",
    "GetPassportElement",
    "GetPasswordState",
    "GetPaymentForm",
    "GetPaymentReceipt",
    "GetPhoneNumberInfo",
    "GetPollVoters",
    "GetPreferredCountryLanguage",
    "GetProxies",
    "GetProxyLink",
    "GetPushReceiverId",
    "GetRecentInlineBots",
    "GetRecentStickers",
    "GetRecentlyVisitedTMeUrls",
    "GetRecommendedChatFilters",
    "GetRecoveryEmailAddress",
    "GetRemoteFile",
    "GetRepliedMessage",
    "GetSavedAnimations",
    "GetSavedOrderInfo",
    "GetScopeNotificationSettings",
    "GetSecretChat",
    "GetStatisticalGraph",
    "GetStickerEmojis",
    "GetStickerSet",
    "GetStickers",
    "GetStorageStatistics",
    "GetStorageStatisticsFast",
    "GetSuggestedFileName",
    "GetSuggestedStickerSetName",
    "GetSuitableDiscussionChats",
    "GetSupergroup",
    "GetSupergroupFullInfo",
    "GetSupergroupMembers",
    "GetSupportUser",
    "GetTemporaryPasswordState",
    "GetTextEntities",
    "GetTopChats",
    "GetTrendingStickerSets",
    "GetUser",
    "GetUserFullInfo",
    "GetUserPrivacySettingRules",
    "GetUserProfilePhotos",
    "GetVoiceChatAvailableParticipants",
    "GetWebPageInstantView",
    "GetWebPagePreview",
    "HideSuggestedAction",
    "ImportContacts",
    "ImportMessages",
    "InviteGroupCallParticipants",
    "JoinChat",
    "JoinChatByInviteLink",
    "JoinGroupCall",
    "LeaveChat",
    "LeaveGroupCall",
    "LoadGroupCallParticipants",
    "LogOut",
    "OpenChat",
    "OpenMessageContent",
    "OptimizeStorage",
    "ParseMarkdown",
    "ParseTextEntities",
    "PinChatMessage",
    "PingProxy",
    "ProcessPushNotification",
    "ReadAllChatMentions",
    "ReadFilePart",
    "RecoverAuthenticationPassword",
    "RecoverPassword",
    "RegisterDevice",
    "RegisterUser",
    "RemoveBackground",
    "RemoveChatActionBar",
    "RemoveContacts",
    "RemoveFavoriteSticker",
    "RemoveNotification",
    "RemoveNotificationGroup",
    "RemoveProxy",
    "RemoveRecentHashtag",
    "RemoveRecentSticker",
    "RemoveRecentlyFoundChat",
    "RemoveSavedAnimation",
    "RemoveStickerFromSet",
    "RemoveTopChat",
    "ReorderChatFilters",
    "ReorderInstalledStickerSets",
    "ReplacePrimaryChatInviteLink",
    "ReportChat",
    "ReportChatPhoto",
    "ReportSupergroupSpam",
    "RequestAuthenticationPasswordRecovery",
    "RequestPasswordRecovery",
    "RequestQrCodeAuthentication",
    "ResendAuthenticationCode",
    "ResendChangePhoneNumberCode",
    "ResendEmailAddressVerificationCode",
    "ResendMessages",
    "ResendPhoneNumberConfirmationCode",
    "ResendPhoneNumberVerificationCode",
    "ResendRecoveryEmailAddressCode",
    "ResetAllNotificationSettings",
    "ResetBackgrounds",
    "ResetNetworkStatistics",
    "ResetPassword",
    "RevokeChatInviteLink",
    "RevokeGroupCallInviteLink",
    "SaveApplicationLogEvent",
    "SearchBackground",
    "SearchCallMessages",
    "SearchChatMembers",
    "SearchChatMessages",
    "SearchChatRecentLocationMessages",
    "SearchChats",
    "SearchChatsNearby",
    "SearchChatsOnServer",
    "SearchContacts",
    "SearchEmojis",
    "SearchHashtags",
    "SearchInstalledStickerSets",
    "SearchMessages",
    "SearchPublicChat",
    "SearchPublicChats",
    "SearchSecretMessages",
    "SearchStickerSet",
    "SearchStickerSets",
    "SearchStickers",
    "SendBotStartMessage",
    "SendCallDebugInformation",
    "SendCallRating",
    "SendCallSignalingData",
    "SendChatAction",
    "SendChatScreenshotTakenNotification",
    "SendCustomRequest",
    "SendEmailAddressVerificationCode",
    "SendInlineQueryResultMessage",
    "SendMessage",
    "SendMessageAlbum",
    "SendPassportAuthorizationForm",
    "SendPaymentForm",
    "SendPhoneNumberConfirmationCode",
    "SendPhoneNumberVerificationCode",
    "SetAccountTtl",
    "SetAlarm",
    "SetAuthenticationPhoneNumber",
    "SetAutoDownloadSettings",
    "SetBackground",
    "SetBio",
    "SetBotUpdatesStatus",
    "SetChatClientData",
    "SetChatDescription",
    "SetChatDiscussionGroup",
    "SetChatDraftMessage",
    "SetChatLocation",
    "SetChatMemberStatus",
    "SetChatMessageTtlSetting",
    "SetChatNotificationSettings",
    "SetChatPermissions",
    "SetChatPhoto",
    "SetChatSlowModeDelay",
    "SetChatTitle",
    "SetCommands",
    "SetCustomLanguagePack",
    "SetCustomLanguagePackString",
    "SetDatabaseEncryptionKey",
    "SetFileGenerationProgress",
    "SetGameScore",
    "SetGroupCallParticipantIsSpeaking",
    "SetGroupCallParticipantVolumeLevel",
    "SetGroupCallTitle",
    "SetInlineGameScore",
    "SetLocation",
    "SetLogStream",
    "SetLogTagVerbosityLevel",
    "SetLogVerbosityLevel",
    "SetName",
    "SetNetworkType",
    "SetOption",
    "SetPassportElement",
    "SetPassportElementErrors",
    "SetPassword",
    "SetPinnedChats",
    "SetPollAnswer",
    "SetProfilePhoto",
    "SetRecoveryEmailAddress",
    "SetScopeNotificationSettings",
    "SetStickerPositionInSet",
    "SetStickerSetThumbnail",
    "SetSupergroupStickerSet",
    "SetSupergroupUsername",
    "SetTdlibParameters",
    "SetUserPrivacySettingRules",
    "SetUsername",
    "SetVoiceChatDefaultParticipant",
    "SharePhoneNumber",
    "StartGroupCallRecording",
    "StartGroupCallScreenSharing",
    "StartScheduledGroupCall",
    "StopPoll",
    "SynchronizeLanguagePack",
    "TerminateAllOtherSessions",
    "TerminateSession",
    "TestCallBytes",
    "TestCallEmpty",
    "TestCallString",
    "TestCallVectorInt",
    "TestCallVectorIntObject",
    "TestCallVectorString",
    "TestCallVectorStringObject",
    "TestGetDifference",
    "TestNetwork",
    "TestProxy",
    "TestReturnError",
    "TestSquareInt",
    "TestUseUpdate",
    "ToggleChatDefaultDisableNotification",
    "ToggleChatIsMarkedAsUnread",
    "ToggleChatIsPinned",
    "ToggleGroupCallEnabledStartNotification",
    "ToggleGroupCallIsMyVideoEnabled",
    "ToggleGroupCallIsMyVideoPaused",
    "ToggleGroupCallMuteNewParticipants",
    "ToggleGroupCallParticipantIsHandRaised",
    "ToggleGroupCallParticipantIsMuted",
    "ToggleGroupCallScreenSharingIsPaused",
    "ToggleMessageSenderIsBlocked",
    "ToggleSupergroupIsAllHistoryAvailable",
    "ToggleSupergroupIsBroadcastGroup",
    "ToggleSupergroupSignMessages",
    "TransferChatOwnership",
    "UnpinAllChatMessages",
    "UnpinChatMessage",
    "UpgradeBasicGroupChatToSupergroupChat",
    "UploadFile",
    "UploadStickerFile",
    "ValidateOrderInfo",
    "ViewMessages",
    "ViewTrendingStickerSets",
    "WriteGeneratedFilePart",
]
